package com.fs.live.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.live.domain.LiveAfterSales;
import com.fs.live.service.ILiveAfterSalesService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 售后记录Controller
 * 
 * @author fs
 * @date 2025-07-08
 */
@RestController
@RequestMapping("/live/liveAfteraSales")
public class LiveAfterSalesController extends BaseController
{
    @Autowired
    private ILiveAfterSalesService liveAfterSalesService;

    /**
     * 查询售后记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:list')")
    @GetMapping("/list")
    public TableDataInfo list(LiveAfterSales liveAfterSales)
    {
        startPage();
        List<LiveAfterSales> list = liveAfterSalesService.selectLiveAfterSalesList(liveAfterSales);
        return getDataTable(list);
    }

    /**
     * 导出售后记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:export')")
    @Log(title = "售后记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveAfterSales liveAfterSales)
    {
        List<LiveAfterSales> list = liveAfterSalesService.selectLiveAfterSalesList(liveAfterSales);
        ExcelUtil<LiveAfterSales> util = new ExcelUtil<LiveAfterSales>(LiveAfterSales.class);
        return util.exportExcel(list, "售后记录数据");
    }

    /**
     * 获取售后记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(liveAfterSalesService.selectLiveAfterSalesById(id));
    }

    /**
     * 新增售后记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:add')")
    @Log(title = "售后记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LiveAfterSales liveAfterSales)
    {
        return toAjax(liveAfterSalesService.insertLiveAfterSales(liveAfterSales));
    }

    /**
     * 修改售后记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:edit')")
    @Log(title = "售后记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LiveAfterSales liveAfterSales)
    {
        return toAjax(liveAfterSalesService.updateLiveAfterSales(liveAfterSales));
    }

    /**
     * 删除售后记录
     */
    @PreAuthorize("@ss.hasPermi('live:liveAfteraSales:remove')")
    @Log(title = "售后记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(liveAfterSalesService.deleteLiveAfterSalesByIds(ids));
    }
}
