package com.fs.live.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.live.domain.LiveUserLike;
import com.fs.live.service.ILiveUserLikeService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 用户直播赞Controller
 * 
 * @author fs
 * @date 2025-07-11
 */
@RestController
@RequestMapping("/live/liveUserLike")
public class LiveUserLikeController extends BaseController
{
    @Autowired
    private ILiveUserLikeService liveUserLikeService;

    /**
     * 查询用户直播赞列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:list')")
    @GetMapping("/list")
    public TableDataInfo list(LiveUserLike liveUserLike)
    {
        startPage();
        List<LiveUserLike> list = liveUserLikeService.selectLiveUserLikeList(liveUserLike);
        return getDataTable(list);
    }

    /**
     * 导出用户直播赞列表
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:export')")
    @Log(title = "用户直播赞", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveUserLike liveUserLike)
    {
        List<LiveUserLike> list = liveUserLikeService.selectLiveUserLikeList(liveUserLike);
        ExcelUtil<LiveUserLike> util = new ExcelUtil<LiveUserLike>(LiveUserLike.class);
        return util.exportExcel(list, "用户直播赞数据");
    }

    /**
     * 获取用户直播赞详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(liveUserLikeService.selectLiveUserLikeById(id));
    }

    /**
     * 新增用户直播赞
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:add')")
    @Log(title = "用户直播赞", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LiveUserLike liveUserLike)
    {
        return toAjax(liveUserLikeService.insertLiveUserLike(liveUserLike));
    }

    /**
     * 修改用户直播赞
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:edit')")
    @Log(title = "用户直播赞", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LiveUserLike liveUserLike)
    {
        return toAjax(liveUserLikeService.updateLiveUserLike(liveUserLike));
    }

    /**
     * 删除用户直播赞
     */
    @PreAuthorize("@ss.hasPermi('live:liveUserLike:remove')")
    @Log(title = "用户直播赞", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(liveUserLikeService.deleteLiveUserLikeByIds(ids));
    }
}
