package com.fs.company.controller.course;

import com.fs.common.annotation.Log;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.domain.R;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.ServletUtils;
import com.fs.common.utils.SortUtils;
import com.fs.course.domain.FsUserCourseTrainingCamp;
import com.fs.course.dto.FsUserCourseTrainingCampDTO;
import com.fs.course.dto.FsUserCourseTrainingCampUpdateDTO;
import com.fs.course.service.IFsUserCourseTrainingCampService;
import com.fs.course.vo.FsUserCourseTrainingCampVO;
import com.fs.framework.security.LoginUser;
import com.fs.framework.service.TokenService;
import com.fs.his.vo.OptionsVO;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

@RestController
@RequestMapping("/course/trainingCamp")
@AllArgsConstructor
public class FsUserCourseTrainingCampController {

    private final IFsUserCourseTrainingCampService fsUserCourseTrainingCampService;
    private final TokenService tokenService;
    /**
     * 查询训练营列表
     */
    @PreAuthorize("@ss.hasPermi('course:trainingCamp:list')")
    @GetMapping("/list")
    public AjaxResult list(@RequestParam(required = false) String trainingCampName,
                           @RequestParam String scs,
                           @RequestParam(required = false, defaultValue = "1") Integer pageNum,
                           @RequestParam(required = false, defaultValue = "10") Integer pageSize)
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Map<String, Object> params = new HashMap<>();
        params.put("trainingCampName", trainingCampName);
        params.put("scs", SortUtils.parseSort(scs));
        params.put("companyId", loginUser.getCompany().getCompanyId());

        PageHelper.startPage(pageNum, pageSize);
        List<FsUserCourseTrainingCampVO> list = fsUserCourseTrainingCampService.selectFsUserCourseTrainingCampVOListByMap(params);
        return AjaxResult.success(new PageInfo<>(list));
    }

}
