package com.fs.app.task;


import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.fs.app.service.IpadSendServer;
import com.fs.common.core.redis.RedisCacheT;
import com.fs.common.utils.PubFun;
import com.fs.course.config.CourseConfig;
import com.fs.course.config.CourseMaConfig;
import com.fs.qw.domain.QwIpadServer;
import com.fs.qw.domain.QwUser;
import com.fs.qw.mapper.QwIpadServerMapper;
import com.fs.qw.mapper.QwUserMapper;
import com.fs.qw.service.impl.AsyncSopTestService;
import com.fs.qw.vo.QwSopCourseFinishTempSetting;
import com.fs.qw.vo.QwSopTempSetting;
import com.fs.sop.domain.QwSopLogs;
import com.fs.sop.mapper.QwSopLogsMapper;
import com.fs.sop.service.IQwSopLogsService;
import com.fs.system.domain.SysConfig;
import com.fs.system.mapper.SysConfigMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.*;
import java.util.concurrent.*;
import java.util.function.Function;
import java.util.stream.Collectors;

@Component
@Slf4j
public class SendMsg {

    private final QwUserMapper qwUserMapper;
    private final QwSopLogsMapper qwSopLogsMapper;
    private final IpadSendServer sendServer;
    private final SysConfigMapper sysConfigMapper;
    private final IQwSopLogsService qwSopLogsService;
    private final RedisCacheT<Long> redisCache;
    private final QwIpadServerMapper qwIpadServerMapper;

    @Value("${group-no}")
    private String groupNo;
    private final List<QwUser> qwUserList = Collections.synchronizedList(new ArrayList<>());
    private final Map<Long, Long> qwMap = new ConcurrentHashMap<>();


    public SendMsg(QwUserMapper qwUserMapper, QwSopLogsMapper qwSopLogsMapper, IpadSendServer sendServer, SysConfigMapper sysConfigMapper, IQwSopLogsService qwSopLogsService, RedisCacheT<Long> redisCache, QwIpadServerMapper qwIpadServerMapper) {
        this.qwUserMapper = qwUserMapper;
        this.qwSopLogsMapper = qwSopLogsMapper;
        this.sendServer = sendServer;
        this.sysConfigMapper = sysConfigMapper;
        this.qwSopLogsService = qwSopLogsService;
        this.redisCache = redisCache;
        this.qwIpadServerMapper = qwIpadServerMapper;
    }
    private List<QwUser> getQwUserList() {
        if (qwUserList.isEmpty()) {
//            List<QwUser> qwUsers = qwUserMapper.selectList(new QueryWrapper<QwUser>().eq("send_msg_type", 1).eq("server_status", 1).eq("ipad_status", 1).isNotNull("server_id").eq("corp_id", corpId));
            List<QwIpadServer> serverList = qwIpadServerMapper.selectList(new QueryWrapper<QwIpadServer>().eq("group_no", groupNo));
            if(serverList.isEmpty()){
                return new ArrayList<>();
            }
            List<Long> serverIds = PubFun.listToNewList(serverList, QwIpadServer::getId);
            List<QwUser> qwUsers = qwUserMapper.selectList(new QueryWrapper<QwUser>().eq("send_msg_type", 1).eq("server_status", 1).eq("ipad_status", 1).in("server_id", serverIds));
            qwUserList.addAll(qwUsers);
        }
        return qwUserList;
    }

    private Map<String, CourseMaConfig> getMiniMap() {
        SysConfig maConfig = sysConfigMapper.selectConfigByConfigKey("courseMa.config");
        List<CourseMaConfig> courseMaConfigs = JSON.parseArray(maConfig.getConfigValue(), CourseMaConfig.class);
        return PubFun.listToMapByGroupObject(courseMaConfigs, CourseMaConfig::getAppid);
    }


    @Scheduled(fixedRate = 50000) // 每10秒执行一次
    public void refulsQwUserList() {
        qwUserList.clear();
    }

    @Scheduled(fixedRate = 10000) // 每10秒执行一次
    public void sendMsg2() {
        log.info("执行日志：{}", LocalDateTime.now());
        if (StringUtils.isEmpty(groupNo)) {
            log.error("corpId为空不执行");
            return;
        }
        SysConfig courseConfig = sysConfigMapper.selectConfigByConfigKey("course.config");
        CourseConfig config = JSON.parseObject(courseConfig.getConfigValue(), CourseConfig.class);
        // 消息发送延迟
        int delayStart;
        int delayEnd;
        if (config.getDelayStart() == null || config.getDelayEnd() == null) {
            log.debug("消息发送延迟为空手动设置1000ms - 2000ms");
            delayStart = 1000;
            delayEnd = 2000;
        } else {
            delayStart = config.getDelayStart();
            delayEnd = config.getDelayEnd();
        }
        Map<String, CourseMaConfig> miniMap = getMiniMap();

        List<QwUser> qwUsers = getQwUserList();
        qwUsers.parallelStream().forEach(e -> {
            if (qwMap.putIfAbsent(e.getId(), System.currentTimeMillis()) == null) {
//                log.info("提交销售任务：{}", e.getQwUserName());
                // 判断企微是否发送消息，是否为ipad发送并且判断是否真实在线
                new Thread(() -> {
                    try {
                        processUser(e, delayStart, delayEnd, miniMap);
                    } catch (Exception exception){
                        log.error("发送错误：", exception);
                    }
                    log.info("销售删除线程：{}", e.getQwUserName());
                    qwMap.remove(e.getId());
                }).start();
            }
        });
    }

    private void processUser(QwUser qwUser, int delayStart, int delayEnd, Map<String, CourseMaConfig> miniMap) {
        long start1 = System.currentTimeMillis();
        List<QwSopLogs> qwSopLogList = qwSopLogsMapper.selectByQwUserId(qwUser.getId());
        if(qwSopLogList.isEmpty()){
            return;
        }
        QwUser user = qwUserMapper.selectById(qwUser.getId());
        long end1 = System.currentTimeMillis();
        if (!sendServer.isSend(user)) {
            qwMap.remove(user.getId());
            return;
        }
        log.info("销售：{}, 消息：{}, 耗时: {}", user.getQwUserName(), qwSopLogList.size(), end1 - start1);
        long start3 = System.currentTimeMillis();
        for (QwSopLogs qwSopLogs : qwSopLogList) {

            long start2 = System.currentTimeMillis();
            QwSopCourseFinishTempSetting setting = JSON.parseObject(qwSopLogs.getContentJson(), QwSopCourseFinishTempSetting.class);
            // 判断消息状态是否满足发送条件
            if (!sendServer.isSendLogs(qwSopLogs, setting, user)) {
                log.info("销售：{}, 消息发送条件未满足：{}", user.getQwUserName(), qwSopLogs.getId());
                continue;
            }
            for (QwSopCourseFinishTempSetting.Setting content : setting.getSetting()) {
                sendServer.send(content, user, qwSopLogs, miniMap);
                if(content.getSendStatus() == 2 && "请求失败：消息发送过于频繁，请稍后再试".equals(content.getSendRemarks())){
                    QwUser update = new QwUser();
                    update.setRemark("请求频率异常，暂停发送，三小时后恢复继续发送");
                    update.setUpdateTime(new Date());
                    qwUserMapper.update(update, new QueryWrapper<QwUser>().eq("id", user.getId()));
                    redisCache.setCacheObject("qw:user:id:" + user.getId(), user.getId(), 3, TimeUnit.HOURS);
                    return;
                }
                try {
                    int delay = ThreadLocalRandom.current().nextInt(300, 1000);
                    log.debug("等待：{}ms", delay);
                    Thread.sleep(delay);
                } catch (InterruptedException e) {
                    log.error("线程等待错误！");
                }
            }
//            if (!setting.getSetting().isEmpty()) {
//                new Thread(() -> {
//                    try {
//                        List<QwSopTempSetting.Content.Setting> settings = JSON.parseArray(JSON.toJSONString(setting.getSetting()), QwSopTempSetting.Content.Setting.class).stream().filter(e -> "9".equals(e.getContentType())).collect(Collectors.toList());
//                        asyncSopTestService.asyncSendMsgBySopAppLinkNormalIM(settings, qwSopLogs.getCorpId(), user.getCompanyUserId(), qwSopLogs.getFsUserId());
//                    } catch (Exception e) {
//                        log.error("推送APP失败", e);
//                    }
//                }).start();
//            }
            qwSopLogs.setSend(true);
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            QwSopLogs updateQwSop = new QwSopLogs();
            updateQwSop.setId(qwSopLogs.getId());
            // 是否全部发送失败
            if (setting.getSetting().stream().allMatch(e -> e.getSendStatus() == 2)) {
                updateQwSop.setReceivingStatus(0L);
                updateQwSop.setSendStatus(0L);
                updateQwSop.setRemark("全部发送失败");
            } else if (setting.getSetting().stream().anyMatch(e -> e.getSendStatus() == 2)) {
                updateQwSop.setReceivingStatus(1L);
                updateQwSop.setSendStatus(1L);
                updateQwSop.setRemark("部分发送失败");
                updateQwSop.setRealSendTime(sdf.format(new Date()));
            } else {
                updateQwSop.setReceivingStatus(1L);
                updateQwSop.setSendStatus(1L);
                updateQwSop.setRemark("全部发送成功");
                updateQwSop.setRealSendTime(sdf.format(new Date()));
            }
            updateQwSop.setContentJson(JSON.toJSONString(setting));

            long end2 = System.currentTimeMillis();
            new Thread(() -> {
                int i = qwSopLogsService.updateQwSopLogsSendType(updateQwSop);
                log.info("销售：{}, 修改条数{}, 发送方消息完成：{}, 耗时: {}", user.getQwUserName(), i, qwSopLogs.getId(),end2 - start2);
            }).start();
            try {
                int delay = ThreadLocalRandom.current().nextInt(delayStart, delayEnd);
                log.debug("等待：{}ms", delay);
                Thread.sleep(delay);
            } catch (InterruptedException e) {
                log.error("线程等待错误！");
            }
        }
        long end3 = System.currentTimeMillis();
        log.info("销售执行完成：{}, 耗时：{}", user.getQwUserName(), end3 - start3);
    }
}
