package com.fs.app.controller;

import com.fs.app.annotation.Login;
import com.fs.common.core.domain.R;
import com.fs.live.domain.LiveData;
import com.fs.live.service.ILiveDataService;
import com.fs.live.service.ILiveWatchUserService;
import com.fs.live.vo.LiveWatchUserVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/app/live/liveData")
public class LiveDataController extends AppBaseController{

    @Autowired
    private ILiveDataService liveDataService;

    @Autowired
    private ILiveWatchUserService liveWatchUserService;
    /**
     * 查询直播数据列表
     * */
    @Login
    @GetMapping("/list")
    public List<LiveData> list(LiveData liveData) {
        return liveDataService.selectLiveDataList(liveData);
    }

    /**
     * 查询直播数据详情
     * */
    @Login
    @GetMapping("/get/{liveId}")
    public R getLiveData(@PathVariable("liveId") Long liveId) {
        return R.ok().put("liveData", liveDataService.selectLiveDataByLiveId(liveId));
    }

    /**
     * 点赞
     * */
    @Login
    @GetMapping("/like/{liveId}")
    public R like(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.updateLikeByLiveId(liveId, Long.parseLong(getUserId())));
    }

    /**
     * 收藏
     * */
    @Login
    @GetMapping("/collect/{liveId}")
    public R collect(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.collect(liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 关注
     * */
    @Login
    @GetMapping("/follow/{liveId}")
    public R follow(@PathVariable("liveId") Long liveId) {
        return R.ok(liveDataService.follow(liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 收藏店铺/店铺商品
     * */
    @Login
    @GetMapping("/collectStore")
    public R collectStore(Long storeId, Long productId, Long liveId) {
        return R.ok(liveDataService.collectStore(storeId, productId, liveId,  Long.parseLong(getUserId())));
    }

    /**
     * 获取直播内数据
     * */
    @GetMapping("/getLiveViewData")
    public R getLiveViewData(Long liveId) {
        Map<String,Object> liveViewData =liveDataService.getLiveViewData(liveId);
        return R.ok(liveViewData);
    }

    /**
     * 获取发言最多的三个用户
     * */
    @GetMapping("/getRecentLiveViewers/{liveId}")
    public R getRecentLiveViewers(@PathVariable  Long liveId) {
        Map<String, Object> params = new HashMap<>();
        params.put("liveId", liveId);
        List<LiveWatchUserVO> recentLiveViewers = liveWatchUserService.selectWatchUserList(params);
        return R.ok().put("recentLiveViewers", recentLiveViewers);
    }


}
