package com.fs.app.controller;

import cn.hutool.core.util.StrUtil;
import com.fs.app.annotation.Login;
import com.fs.app.utils.JwtUtils;
import com.fs.common.annotation.Log;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.domain.R;
import com.fs.common.core.page.TableDataInfo;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.StringUtils;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.his.dto.ExpressInfoDTO;
import com.fs.his.enums.ShipperCodeEnum;
import com.fs.his.service.IFsExpressService;
import com.fs.live.domain.LiveOrder;
import com.fs.live.enums.LiveOrderCancleReason;
import com.fs.live.service.ILiveOrderService;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

import static com.fs.his.utils.PhoneUtil.decryptPhone;
import static com.github.pagehelper.page.PageMethod.startPage;

/**
 * 订单Controller
 *
 * @author fs
 * @date 2025-07-08
 */
@RestController
@RequestMapping("/app/live/liveOrder")
public class LiveOrderController extends AppBaseController
{
    @Autowired
    private ILiveOrderService liveOrderService;


    @Autowired
    private IFsExpressService expressService;
    @Autowired
    private JwtUtils jwtUtils;

    /**
     * 查询订单列表
     */
    @Login
    @GetMapping("/list")
    public TableDataInfo list(LiveOrder liveOrder)
    {
        PageHelper.startPage(liveOrder.getPageNum(), liveOrder.getPageSize());
        liveOrder.setUserId(getUserId());
        List<LiveOrder> list = liveOrderService.selectLiveOrderList(liveOrder);
        return getDataTable(list);
    }

    /**
     * 导出订单列表
     */
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveOrder liveOrder)
    {
        List<LiveOrder> list = liveOrderService.selectLiveOrderList(liveOrder);
        ExcelUtil<LiveOrder> util = new ExcelUtil<LiveOrder>(LiveOrder.class);
        return util.exportExcel(list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @Login
    @GetMapping(value = "/info/{orderId}")
    public AjaxResult getInfo(@PathVariable("orderId") String orderId)
    {
        return AjaxResult.success(liveOrderService.selectLiveOrderByOrderId(orderId));
    }

    /**
     * 新增订单
     */
    @Login
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping("/create")
    public R add(@RequestBody LiveOrder liveOrder)
    {
        return R.ok().put("orderId", liveOrderService.insertLiveOrder(liveOrder));
    }

    /**
     * 修改订单
     */
    @Login
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping("/update")
    public R edit(@RequestBody LiveOrder liveOrder)
    {
        return R.ok().put("orderId",liveOrder.getOrderId());
    }


    /**
     * 查看物流状态
     * */
    @Login
    @GetMapping(value = "/getExpress/{id}")
    public R getExpress(@PathVariable("id") String id)
    {
        LiveOrder order=liveOrderService.selectLiveOrderByOrderId(id);
        ExpressInfoDTO expressInfoDTO=null;
        if(StringUtils.isNotEmpty(order.getDeliverySn())){
            String lastFourNumber = "";
            if (order.getDeliveryCode().equals(ShipperCodeEnum.SF.getValue())) {

                lastFourNumber = order.getUserPhone();
                if (lastFourNumber.length() == 11) {
                    lastFourNumber = StrUtil.sub(lastFourNumber, lastFourNumber.length(), -4);
                }else if (lastFourNumber.length()>11){
                    String jm = decryptPhone(lastFourNumber);
                    lastFourNumber = StrUtil.sub(jm, jm.length(), -4);
                }
            }
            expressInfoDTO=expressService.getExpressInfo(order.getOrderCode(),order.getDeliveryCode(),order.getDeliverySn(),lastFourNumber);

            if((expressInfoDTO.getStateEx()!=null&&expressInfoDTO.getStateEx().equals("0"))&&(expressInfoDTO.getState()!=null&&expressInfoDTO.getState().equals("0"))){
                lastFourNumber = "19923690275";
                if (order.getDeliveryCode().equals(ShipperCodeEnum.SF.getValue())) {
                    if (lastFourNumber.length() == 11) {
                        lastFourNumber = StrUtil.sub(lastFourNumber, lastFourNumber.length(), -4);
                    }
                }

                expressInfoDTO=expressService.getExpressInfo(order.getOrderCode(),order.getDeliveryCode(),order.getDeliverySn(),lastFourNumber);

            }
        }
        return R.ok().put("data",expressInfoDTO);
    }

    /**
     * 支付订单
     * */
    @PostMapping(value = "/pay")
    public void pay(LiveOrder liveOrder)
    {
       liveOrderService.handlePay(liveOrder);
    }

    /**
     * 订单确认
     * */
    @Login
    @GetMapping(value = "/updateConfirm/{orderId}/{type}")
    public R cancelConfirm(@PathVariable String orderId,@PathVariable String type)
    {
        LiveOrder byId = liveOrderService.getById(orderId);
        List<Map<String, String>> allCodeDescMap = null;
        if (type.equals("0"))
            allCodeDescMap = LiveOrderCancleReason.getAllCodeDescMap();
        return R.ok().put("reason",allCodeDescMap).put("data",byId);
    }

    /**
     *正在购买的用户
     * */
    @GetMapping(value = "/liveOrderUser/{liveId}")
    public R liveOrderUser(@PathVariable  String liveId)
    {
        return liveOrderService.liveOrderUser(liveId);
    }



}
