package com.fs.app.controller;


import cn.hutool.core.date.DateTime;
import com.fs.app.annotation.Login;
import com.fs.app.param.FsUserLoginParam;
import com.fs.app.param.LoginParam;
import com.fs.app.websocket.constant.NickNameConstant;
import com.fs.common.constant.Constants;
import com.fs.common.core.domain.R;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.exception.user.CaptchaException;
import com.fs.common.exception.user.CaptchaExpireException;
import com.fs.common.utils.MessageUtils;
import com.fs.common.utils.StringUtils;
import com.fs.common.utils.sign.Md5Utils;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyPostService;
import com.fs.company.service.ICompanyUserService;
import com.fs.framework.manager.AsyncManager;
import com.fs.framework.manager.factory.AsyncFactory;
import com.fs.his.domain.FsUser;
import com.fs.his.mapper.FsUserMapper;
import com.fs.his.service.IFsUserNewTaskService;
import com.fs.his.service.IFsUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import me.chanjar.weixin.common.bean.WxOAuth2UserInfo;
import me.chanjar.weixin.common.bean.oauth2.WxOAuth2AccessToken;
import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.api.WxMpUserService;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.*;
import java.util.concurrent.TimeUnit;

import static com.fs.his.utils.PhoneUtil.encryptPhone;


@Api("用户接口")
@RestController
@AllArgsConstructor
@RequestMapping(value="/app/user")
public class UserController extends AppBaseController {
	private final ICompanyPostService postService;
	private final ICompanyUserService companyUserService;
	private final RedisCache redisCache;
	private final WxMpService wxMpService;
	private final IFsUserService userService;

	private final Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private FsUserMapper userMapper;
	@Autowired
	private IFsUserNewTaskService userNewTaskService;


	@ApiOperation("课程短链公众号登录")
	@PostMapping("/loginByMp")
	public R loginByMp( @RequestBody LoginParam param) {
		if (StringUtils.isBlank(param.getCode())) {
			return R.error("code不存在");
		}
		try{
			WxOAuth2AccessToken wxMpOAuth2AccessToken = wxMpService.getOAuth2Service().getAccessToken(param.getCode());
			WxOAuth2UserInfo wxMpUser = wxMpService.getOAuth2Service().getUserInfo(wxMpOAuth2AccessToken, null);
			WxMpUserService wxMpUserService = wxMpService.getUserService();
			WxMpUser userInfo = wxMpUserService.userInfo(wxMpUser.getOpenid());
			if (!userInfo.getSubscribe()){
				return R.error("请关注公众号进行登录");
			}
			FsUser user=userService.selectFsUserByUnionid(param.getUnionId());
			if(user!=null){
				FsUser userMap=new FsUser();
				userMap.setUserId(user.getUserId());
				userMap.setNickName(wxMpUser.getNickname());
				userMap.setAvatar(wxMpUser.getHeadImgUrl());
				userMap.setMpOpenId(wxMpUser.getOpenid());
				userMap.setUpdateTime(new DateTime());
				userService.updateFsUser(userMap);
			}
			else{
				//写入
				user=new FsUser();
				user.setNickName(wxMpUser.getNickname());
				user.setAvatar(wxMpUser.getHeadImgUrl());
				user.setStatus(1);
				user.setSex(wxMpUser.getSex());
				user.setMpOpenId(wxMpUser.getOpenid());
				user.setUnionId(wxMpUser.getUnionId());
				user.setCreateTime(new Date());
				userService.insertFsUser(user);
			}
			String token = jwtUtils.generateToken(user.getUserId());
			redisCache.setCacheObject("token:"+user.getUserId(),token,604800, TimeUnit.SECONDS);
			Map<String,Object> map=new HashMap<>();
			map.put("token",token);
			map.put("user",user);
			return R.ok(map);
		}
		catch (WxErrorException e){
			if(e.getError().getErrorCode()==40163){
				return R.error(40163,e.getError().getErrorMsg());
			}
			else{
				return R.error("授权失败,"+e.getMessage());
			}
		}

	}

	@ApiOperation("检测是否登录")
	@GetMapping("/checkLogin")
	public R checkLogin(){
		if(StringUtils.isEmpty(getUserId())){
			//未登录
			return R.error("未登录");
		}
		else{
			//登录
			String token = jwtUtils.generateToken(Long.parseLong(getUserId()));
			Map<String,Object> map=new HashMap<>();
			map.put("token",token);
			return R.ok("认证成功").put("userId",getUserId()).put("token",token);
		}
	}

	/**
	 * 获取用户信息
	 */
	@Login
	@ApiOperation("获取用户信息")
	@GetMapping("/getUserInfo")
	public R getUserInfo(){
		try {
			CompanyUser companyUser=companyUserService.selectCompanyUserById(Long.parseLong(getUserId()));
			List<String> postList=postService.selectPostNameListByUserId(Long.parseLong(getUserId()));
			if(companyUser==null){
				return R.error(40001,"用户不存在");
			}
			if(companyUser.getStatus().equals("1")){
				return R.error(40002,"用户已停用");
			}
			return R.ok().put("user",companyUser).put("post",postList);
		} catch (Exception e){

			return R.error("操作异常");
		}
	}
	@Login
	@ApiOperation("获取用户信息ByUserId")
	@GetMapping("/getUserInfoByUserId")
	public R getUserInfoByUserId(
			@ApiParam(required = true, name = "userId", value = "用户ID") @RequestParam(value = "userId", required = false) Long userId,
			HttpServletRequest request){
		try {
			CompanyUser user=companyUserService.selectCompanyUserById(userId);
			List<String> postList=postService.selectPostNameListByUserId(userId);
			if(user==null){
				return R.error(40001,"用户不存在");
			}
			if(user.getStatus().equals("1")){
				return R.error(40002,"用户已停用");
			}
			return R.ok().put("user",user).put("post",postList);
		} catch (Exception e){

			return R.error("操作异常");
		}
	}


	/**
	 * app登录
	 * */
	@ApiOperation("登录")
	@PostMapping("/loginByApp")
	@Transactional
	public R login(@Validated @RequestBody FsUserLoginParam param) {
		int loginType = param.getLoginType();
		switch (loginType) {
			case 1:
				return handleLoginType1(param);
			case 3:
				return handleLoginType3(param);
			default:
				return R.error("请选择正确的登陆类型！");
		}
	}

	private R handleLoginType1(FsUserLoginParam param) {

		if (org.apache.commons.lang3.StringUtils.isEmpty(param.getPhone()) || org.apache.commons.lang3.StringUtils.isEmpty(param.getPassword())) {
			return R.error("账号或密码不能为空");
		}

		FsUser user = findUserByPhone(param.getPhone());

		// 校验用户是否存在及账号状态
		if (user == null) {
			return R.error("账号不存在，请先注册账号");
		} else if (user.getStatus() == 0) {
			return R.error("账号已停用");
		} else if (org.apache.commons.lang3.StringUtils.isEmpty(user.getPassword())) {
			return R.error("账号不存在，请先注册账号");
		}

		if (!Md5Utils.hash(param.getPassword()).equals(user.getPassword())) {
			return R.error("密码不正确");
		}

		return generateTokenAndReturn(user);

	}

	private R handleLoginType3(FsUserLoginParam param) {
		if (org.apache.commons.lang3.StringUtils.isEmpty(param.getPhone())) {
			return R.error("获取手机号失败");
		}
		// 根据手机号查询用户
		FsUser user = findUserByPhone(param.getPhone());
		if (user == null) {
			user = createNewUser(param);
			//return R.ok().put("isNew",true).put("phone",encryptPhone(param.getPhone()));
		} else {
			if (user.getUnionId()==null){
				if (user.getPhone().length()<=11){
					FsUser fsUser = new FsUser();
					fsUser.setUserId(user.getUserId());
					fsUser.setPhone(param.getPhone());
					userMapper.updateFsUser(fsUser);
					logger.info("zyp \n【手机加密】：{}",encryptPhone(param.getPhone()));
				}
				//return R.ok().put("isNew",true).put("phone",encryptPhone(param.getPhone()));
			}
			/*if (org.apache.commons.lang3.StringUtils.isNotEmpty(param.getJpushId())) {
				updateExistingUserJpushId(user, param.getJpushId());
			}*/
		}
		return generateTokenAndReturn(user);
	}

	private void updateExistingUserJpushId(FsUser user, String jpushId) {
		FsUser userMap = new FsUser();
		userMap.setUserId(user.getUserId());
		userMap.setJpushId(jpushId);
		userService.updateFsUser(userMap);
	}

	private R generateTokenAndReturn(FsUser user) {
		String token = jwtUtils.generateToken(user.getUserId());
		redisCache.setCacheObject("userToken:" + user.getUserId(), token, 604800, TimeUnit.SECONDS);
		int isFirstLogin = userNewTaskService.performTaskOne(user.getUserId());
		Map<String, Object> map = new HashMap<>();
		map.put("token", token);
		map.put("user", user);
		map.put("isFirst",isFirstLogin);
		return R.ok(map);
	}

	private FsUser findUserByPhone(String phone) {
		// 先根据加密手机号查询用户
		String jiami = (encryptPhone(phone));
		FsUser user = userMapper.selectFsUserByPhoneLimitOne(jiami);

		// 如果没有找到用户，再根据手机号查询
		if (user == null) {
			user = userMapper.selectFsUserByPhoneLimitOne(phone);

		}
		return user;
	}

	private FsUser createNewUser(FsUserLoginParam param) {
		FsUser newUser = new FsUser();
		newUser.setLoginDevice(param.getLoginDevice() != null ? param.getLoginDevice() : null);
		newUser.setSource(param.getSource() != null ? param.getSource() : null );
		newUser.setNickName(NickNameConstant.getNickName());
		newUser.setPhone(param.getPhone());
		newUser.setCreateTime(new Date());
		newUser.setStatus(1);
		newUser.setAvatar("https://cos.his.cdwjyyh.com/fs/20240926/420728ee06e54575ba82665dedb4756b.png");
		/*if (org.apache.commons.lang3.StringUtils.isNotEmpty(param.getJpushId())) {
			newUser.setJpushId(param.getJpushId());
		}*/
		userService.insertFsUser(newUser);
		return newUser;
	}

	//

}
