package com.fs.app.controller;

import com.fs.common.BeanCopyUtils;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.R;
import com.fs.common.exception.CustomException;
import com.fs.course.param.FsCourseListBySidebarParam;
import com.fs.qw.domain.QwExternalContactInfo;
import com.fs.qw.domain.QwTagGroup;
import com.fs.qw.domain.QwUser;
import com.fs.qw.param.ExternalContactDetailsParam;
import com.fs.qw.param.sidebar.ExternalContactInfoParam;
import com.fs.qw.param.sidebar.TagGroupListParam;
import com.fs.qw.param.sidebar.TagGroupUpdateParam;
import com.fs.qw.service.IQwExternalContactInfoService;
import com.fs.qw.service.IQwExternalContactService;
import com.fs.qw.service.IQwTagGroupService;
import com.fs.qw.service.IQwTagService;
import com.fs.qw.vo.ExternalContactDetailsVO;
import com.fs.qw.vo.QwExternalListByHeavyVO;
import com.fs.qw.vo.QwTagGroupListVO;
import com.fs.qw.vo.sidebar.ExternalContactInfoVO;
import com.fs.qw.vo.sidebar.ExternalContactTagVO;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@Api(tags = "企微会员相关接口")
@RestController
@RequestMapping("/apis/app/qw/user")
public class ApisQwUserController extends BaseController {

    @Autowired
    private IQwExternalContactService qwExternalContactService;

    @Autowired
    private IQwExternalContactInfoService qwExternalContactInfoService;

    @Autowired
    private IQwTagGroupService qwTagGroupService;

    @GetMapping("/details")
    @ApiOperation("会员看课详情")
    public R getUserDetails(@ApiParam(value = "外部联系人id", required = true) @RequestParam Long contactId,
                            @ApiParam(value = "时间tab，不传表示查询全部，分别是：今天、昨天、前天、近七天", required = true) String dateTag) {
        ExternalContactDetailsParam param = new ExternalContactDetailsParam();
        param.setUserId(getUserId());
        param.setContactId(contactId);
        param.setDateTag(dateTag);
        ExternalContactDetailsVO userDetails = qwExternalContactService.getUserDetails(param);
        Map<String, Object> map = new HashMap<>();
        map.put("userDetails", userDetails);
        return R.ok(map);
    }


    @GetMapping("/getQwUserInfo")
    @ApiOperation("获取企微用户信息")
    public R getQwUserInfo(@RequestParam(value = "qwExternalContactId",required = false) Long qwExternalContactId){
        if(qwExternalContactId == null) {
            throw new CustomException("企微外部联系人id不能为空!");
        }
//        QwExternalContact qwExternalContact = qwExternalContactService.selectQwExternalContactById(qwExternalContactId);
        QwExternalContactInfo contactInfo = qwExternalContactInfoService.selectQwExternalContactInfoByExternalContactId(qwExternalContactId);
        if (contactInfo==null){

            contactInfo = new QwExternalContactInfo();
            contactInfo.setExternalContactId(qwExternalContactId);
            qwExternalContactInfoService.insertQwExternalContactInfo(contactInfo);

        }

//        return R.ok().put("data",qwExternalContact).put("moreInfo",contactInfo);
        return R.ok().put("moreInfo",contactInfo);
    }

    @PostMapping("/updateQwUserInfo")
    @ApiOperation("更新企微用户信息")
    public R updateQwUserInfo(@RequestBody QwExternalContactInfo qwExternalContactInfo){
        if(qwExternalContactInfo.getExternalContactId() == null) {
            throw new CustomException("企微外部联系人id不能为空!");
        }
        qwExternalContactInfoService.updateQwExternalContactInfoByExternalContactId(qwExternalContactInfo);
        return R.ok();
    }

    /**
    * 获取客户是否加了其他的销售(重粉)
    */
    @PostMapping("/getQwExternalListByHeavy")
    @ApiOperation("获取客户是否加了其他的销售")
    public R getQwExternalListByHeavy(@RequestBody FsCourseListBySidebarParam param){
        QwUser qwUser = qwExternalContactService.getQwUserByRedis(param.getCorpId().trim(),param.getQwUserId().trim());

        if (qwUser == null) {
            return R.error("未查询到企业微信账号信息！请重试");
        }

        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        List<QwExternalListByHeavyVO> qwExternalListByHeavy = qwExternalContactService.getQwExternalListByHeavy(param);
        PageInfo<QwExternalListByHeavyVO> result = new PageInfo<>(qwExternalListByHeavy);
        return R.ok().put("data", result);
    }

    @GetMapping("/externalContact")
    @ApiOperation("获取侧边栏外部联系人信息")
    public R getExternalContactInfo(@RequestParam(value = "qwExternalContactId") Long qwExternalContactId) {
        ExternalContactInfoVO externalContactInfo = qwExternalContactService.getExternalContactInfo(qwExternalContactId);
        return R.ok().put("data", externalContactInfo);
    }


    @GetMapping("/externalContact/tag")
    @ApiOperation("获取侧边栏外部联系人标签")
    public R getExternalContactTag(@RequestParam(value = "qwExternalContactId") Long qwExternalContactId) {
        List<ExternalContactTagVO> tagList = qwExternalContactService.getExternalContactTag(qwExternalContactId);
        return R.ok().put("data", tagList);
    }

    @PutMapping("/externalContact")
    @ApiOperation("编辑外部联系人信息")
    public R updateExternalContactInfo(@RequestBody ExternalContactInfoParam param) {
        return qwExternalContactService.updateExternalContactInfo(param);
    }

    @GetMapping("/tagGroupList")
    @ApiOperation("获取所有标签组和其下标签")
    public R getTagGroupList(TagGroupListParam param) {
        QwTagGroup qwTagGroup = new QwTagGroup();
        BeanCopyUtils.copy(param, qwTagGroup);
        qwTagGroup.setName(param.getTagName());

        PageHelper.startPage(qwTagGroup.getPageNum(), qwTagGroup.getPageSize());
        List<QwTagGroupListVO> list = qwTagGroupService.selectQwGroupTagList(qwTagGroup);

        PageInfo<QwTagGroupListVO> result = new PageInfo<>(list);
        return R.ok().put("data", result);
    }

//    @GetMapping("/searchTags")
//    @ApiOperation("搜索标签-跟管理端保持一致")
//    public R searchTagList(QwTagParam param) {
//        List<QwTagGroupListVO> list = qwTagService.searchTags(param);
//        return R.ok().put("data", list);
//    }

    @PutMapping("/externalContact/tag")
    @ApiOperation("编辑标签")
    public R updateExternalContactTag(@RequestBody TagGroupUpdateParam param) {
        int i = qwExternalContactService.updateExternalContactTag(param);
        if (i > 0) {
            return R.ok();
        }
        return R.error();
    }


}
