package com.fs.company.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.company.domain.CompanyDomainBind;
import com.fs.company.param.CompanyDomainBindParam;
import com.fs.company.vo.CompanyDomainBindVo;
import org.apache.ibatis.annotations.Param;

/**
 * 域名绑定销售公司Mapper接口
 * 
 * @author fs
 * @date 2025-06-17
 */
public interface CompanyDomainBindMapper extends BaseMapper<CompanyDomainBind>{
    /**
     * 查询域名绑定销售公司
     * 
     * @param id 域名绑定销售公司主键
     * @return 域名绑定销售公司
     */
    CompanyDomainBind selectCompanyDomainBindById(Long id);

    /**
     * 查询域名绑定销售公司列表
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 域名绑定销售公司集合
     */
    List<CompanyDomainBind> selectCompanyDomainBindList(CompanyDomainBindParam companyDomainBind);

    /**
     * 新增域名绑定销售公司
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 结果
     */
    int insertCompanyDomainBind(CompanyDomainBind companyDomainBind);

    /**
     * 修改域名绑定销售公司
     * 
     * @param companyDomainBind 域名绑定销售公司
     * @return 结果
     */
    int updateCompanyDomainBind(CompanyDomainBind companyDomainBind);

    /**
     * 删除域名绑定销售公司
     * 
     * @param id 域名绑定销售公司主键
     * @return 结果
     */
    int deleteCompanyDomainBindById(Long id);

    /**
     * 批量删除域名绑定销售公司
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCompanyDomainBindByIds(Long[] ids);

    /**
     * 批量插入绑定数据
     * @param bindList 数据集合
     * **/
    void batchInsertBindInfo(@Param("bindList") List<CompanyDomainBind> bindList);

    /**
     * 批量删除域名绑定销售公司
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCompanyDomainBindBydomainIds(Long[] ids);

    /**
     * 查询中间表链接信息
     * **/
    List<CompanyDomainBindVo> selectJoinBindInfo(CompanyDomainBindParam companyDomainBind);

    /**
     * 获取绑定用户信息
     * **/
    List<Long> getBindUserByDomainId(@Param("domainId") Long domainId);
}
