package com.fs.course.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.course.domain.FsUserCompanyUser;

import java.util.List;

/**
 * 微信用户和销售关系Service接口
 * 
 * @author fs
 * @date 2025-05-09
 */
public interface IFsUserCompanyUserService extends IService<FsUserCompanyUser>{
    /**
     * 查询微信用户和销售关系
     * 
     * @param id 微信用户和销售关系主键
     * @return 微信用户和销售关系
     */
    FsUserCompanyUser selectFsUserCompanyUserById(Long id);

    /**
     * 查询微信用户和销售关系列表
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 微信用户和销售关系集合
     */
    List<FsUserCompanyUser> selectFsUserCompanyUserList(FsUserCompanyUser fsUserCompanyUser);

    /**
     * 新增微信用户和销售关系
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 结果
     */
    int insertFsUserCompanyUser(FsUserCompanyUser fsUserCompanyUser);

    /**
     * 修改微信用户和销售关系
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 结果
     */
    int updateFsUserCompanyUser(FsUserCompanyUser fsUserCompanyUser);

    /**
     * 批量删除微信用户和销售关系
     * 
     * @param ids 需要删除的微信用户和销售关系主键集合
     * @return 结果
     */
    int deleteFsUserCompanyUserByIds(Long[] ids);

    /**
     * 删除微信用户和销售关系信息
     * 
     * @param id 微信用户和销售关系主键
     * @return 结果
     */
    int deleteFsUserCompanyUserById(Long id);
    /**
     * 根据用户ID和项目ID查询微信用户与销售的关系
     * @param userId            用户ID
     * @param projectId   项目ID
     * @return FsUserCompanyUser
     */
    FsUserCompanyUser selectByUserIdAndProjectId(Long userId, Long projectId);

    /**
     * 查询是否已绑定关系
     * @param userId            用户ID
     * @param companyUserId     销售ID
     * @return  boolean
     */
    boolean hasBind(Long userId, Long companyUserId);

    /**
     * 获取当前销售的所有重粉会员
     * @param userId 销售ID
     * @return  list
     */
    List<FsUserCompanyUser> selectRepeatUser(Long userId);

    /**
     * 获取会员的重粉的所属销售
     * @param userIds   会员ID集合
     * @return  list
     */
    List<FsUserCompanyUser> selectRepeatCompanyUserName(List<Long> userIds);

    /**
     * 绑定会员-项目-销售关系
     * @param userId        会员ID
     * @param projectId     项目ID
     * @param companyId     公司ID
     * @param companyUserId 销售ID
     */
    void bindRelationship(Long userId, Long projectId, Long companyId, Long companyUserId);

    /**
     * 修改会员-项目-销售关系
     * @param userId        会员ID
     * @param projectId     项目ID
     * @param companyId     公司ID
     * @param companyUserId 销售ID
     */
    void changeRelationship(Long userId, Long projectId, Long companyId, Long companyUserId);
}
