package com.fs.course.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.course.domain.FsUserCompanyUser;
import com.fs.course.mapper.FsUserCompanyUserMapper;
import com.fs.course.service.IFsUserCompanyUserService;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;

/**
 * 微信用户和销售关系Service业务层处理
 * 
 * @author fs
 * @date 2025-05-09
 */
@Service
public class FsUserCompanyUserServiceImpl extends ServiceImpl<FsUserCompanyUserMapper, FsUserCompanyUser> implements IFsUserCompanyUserService {

    /**
     * 查询微信用户和销售关系
     * 
     * @param id 微信用户和销售关系主键
     * @return 微信用户和销售关系
     */
    @Override
    public FsUserCompanyUser selectFsUserCompanyUserById(Long id)
    {
        return baseMapper.selectFsUserCompanyUserById(id);
    }

    /**
     * 查询微信用户和销售关系列表
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 微信用户和销售关系
     */
    @Override
    public List<FsUserCompanyUser> selectFsUserCompanyUserList(FsUserCompanyUser fsUserCompanyUser)
    {
        return baseMapper.selectFsUserCompanyUserList(fsUserCompanyUser);
    }

    /**
     * 新增微信用户和销售关系
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 结果
     */
    @Override
    public int insertFsUserCompanyUser(FsUserCompanyUser fsUserCompanyUser)
    {
        return baseMapper.insertFsUserCompanyUser(fsUserCompanyUser);
    }

    /**
     * 修改微信用户和销售关系
     * 
     * @param fsUserCompanyUser 微信用户和销售关系
     * @return 结果
     */
    @Override
    public int updateFsUserCompanyUser(FsUserCompanyUser fsUserCompanyUser)
    {
        return baseMapper.updateFsUserCompanyUser(fsUserCompanyUser);
    }

    /**
     * 批量删除微信用户和销售关系
     * 
     * @param ids 需要删除的微信用户和销售关系主键
     * @return 结果
     */
    @Override
    public int deleteFsUserCompanyUserByIds(Long[] ids)
    {
        return baseMapper.deleteFsUserCompanyUserByIds(ids);
    }

    /**
     * 删除微信用户和销售关系信息
     * 
     * @param id 微信用户和销售关系主键
     * @return 结果
     */
    @Override
    public int deleteFsUserCompanyUserById(Long id)
    {
        return baseMapper.deleteFsUserCompanyUserById(id);
    }

    /**
     * 根据用户ID和项目ID查询微信用户与销售的关系
     * @param userId            用户ID
     * @param projectId   项目ID
     * @return FsUserCompanyUser
     */
    @Override
    public FsUserCompanyUser selectByUserIdAndProjectId(Long userId, Long projectId) {
        LambdaQueryWrapper<FsUserCompanyUser> queryWrapper = Wrappers.<FsUserCompanyUser>lambdaQuery()
                .eq(FsUserCompanyUser::getUserId, userId)
                .eq(FsUserCompanyUser::getProjectId, projectId);
        return getOne(queryWrapper);
    }

    /**
     * 查询是否已绑定关系
     * @param userId            用户ID
     * @param companyUserId     销售ID
     * @return  boolean
     */
    @Override
    public boolean hasBind(Long userId, Long companyUserId) {
        LambdaQueryWrapper<FsUserCompanyUser> queryWrapper = Wrappers.<FsUserCompanyUser>lambdaQuery()
                .eq(FsUserCompanyUser::getUserId, userId)
                .eq(FsUserCompanyUser::getCompanyUserId, companyUserId);
        return count(queryWrapper) > 0;
    }

    /**
     * 获取当前销售的所有重粉会员
     * @param userId 销售ID
     * @return list
     */
    @Override
    public List<FsUserCompanyUser> selectRepeatUser(Long userId) {
        return baseMapper.selectRepeatUser(userId);
    }

    /**
     * 获取会员的重粉的所属销售
     * @param userIds   会员ID集合
     * @return  list
     */
    @Override
    public List<FsUserCompanyUser> selectRepeatCompanyUserName(List<Long> userIds) {
        return baseMapper.selectRepeatCompanyUserName(userIds);
    }

    /**
     * 绑定会员-项目-销售关系
     * @param userId        会员ID
     * @param projectId     项目ID
     * @param companyId     公司ID
     * @param companyUserId 销售ID
     */
    @Override
    public void bindRelationship(Long userId, Long projectId, Long companyId, Long companyUserId) {
        FsUserCompanyUser userCompanyUser = new FsUserCompanyUser();
        userCompanyUser.setUserId(userId);
        userCompanyUser.setProjectId(projectId);
        userCompanyUser.setCompanyId(companyId);
        userCompanyUser.setCompanyUserId(companyUserId);
        boolean hasBind = hasBind(userId, companyUserId);
        userCompanyUser.setIsRepeatFans(hasBind ? 1 : 0);
        save(userCompanyUser);
    }

    /**
     * 修改会员-项目-销售关系
     * @param userId        会员ID
     * @param projectId     项目ID
     * @param companyId     公司ID
     * @param companyUserId 销售ID
     */
    @Override
    public void changeRelationship(Long userId, Long projectId, Long companyId, Long companyUserId) {
        LambdaQueryWrapper<FsUserCompanyUser> queryWrapper = Wrappers.<FsUserCompanyUser>lambdaQuery()
                .eq(FsUserCompanyUser::getUserId, userId)
                .eq(FsUserCompanyUser::getProjectId, projectId)
                .last("limit 1");
        FsUserCompanyUser userCompanyUser = getOne(queryWrapper);
        if (Objects.nonNull(userCompanyUser)) {
            userCompanyUser.setCompanyId(companyId);
            userCompanyUser.setCompanyUserId(companyUserId);
            updateById(userCompanyUser);
        }
    }
}
