package com.fs.course.service.impl;

import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.fs.common.BeanCopyUtils;
import com.fs.common.core.domain.R;
import com.fs.common.core.domain.ResponseResult;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.enums.BizResponseEnum;
import com.fs.common.exception.CustomException;
import com.fs.common.utils.DateUtils;
import com.fs.common.utils.StringUtils;
import com.fs.common.utils.date.DateUtil;
import com.fs.company.domain.Company;
import com.fs.company.domain.CompanyMoneyLogs;
import com.fs.company.domain.CompanyUser;
import com.fs.company.mapper.CompanyMapper;
import com.fs.company.mapper.CompanyMoneyLogsMapper;
import com.fs.company.mapper.CompanyUserMapper;
import com.fs.course.config.CourseConfig;
import com.fs.course.domain.*;
import com.fs.course.dto.CoursePackageDTO;
import com.fs.course.mapper.*;
import com.fs.course.param.*;
import com.fs.course.param.newfs.*;
import com.fs.course.service.IFsUserCourseVideoService;
import com.fs.course.service.IFsVideoResourceService;
import com.fs.course.vo.FsCourseVideoListBySidebarVO;
import com.fs.course.vo.FsUserCourseVideoListUVO;
import com.fs.course.vo.FsUserCourseVideoQVO;
import com.fs.course.vo.FsUserCourseVideoVO;
import com.fs.course.vo.newfs.*;
import com.fs.his.domain.FsUser;
import com.fs.his.domain.FsUserIntegralLogs;
import com.fs.his.domain.FsUserWx;
import com.fs.his.mapper.FsUserIntegralLogsMapper;
import com.fs.his.mapper.FsUserMapper;
import com.fs.his.param.WxSendRedPacketParam;
import com.fs.his.service.IFsStorePaymentService;
import com.fs.his.service.IFsUserService;
import com.fs.his.service.IFsUserWxService;
import com.fs.his.vo.OptionsVO;
import com.fs.qw.domain.QwCompany;
import com.fs.qw.domain.QwExternalContact;
import com.fs.qw.domain.QwUser;
import com.fs.qw.mapper.QwExternalContactMapper;
import com.fs.qw.mapper.QwUserMapper;
import com.fs.qw.service.IQwCompanyService;
import com.fs.qw.service.IQwExternalContactService;
import com.fs.qwApi.Result.QwAddContactWayResult;
import com.fs.qwApi.Result.QwGroupChatDetailsResult;
import com.fs.qwApi.param.QwAddContactWayParam;
import com.fs.qwApi.service.QwApiService;
import com.fs.repeat.vo.RepeatUploadVo;
import com.fs.sop.mapper.QwSopLogsMapper;
import com.fs.sop.mapper.SopUserLogsInfoMapper;
import com.fs.sop.service.ISopUserLogsInfoService;
import com.fs.system.service.ISysConfigService;
import com.fs.voice.utils.StringUtil;
import com.fs.wx.cp.config.WxCpProperties;
import com.github.binarywang.wxpay.bean.transfer.TransferBillsResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.rocketmq.spring.core.RocketMQTemplate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.SocketTimeoutException;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Collectors;

import static com.fs.course.utils.LinkUtil.generateRandomStringWithLock;

/**
 * 课堂视频Service业务层处理
 *
 * @author fs
 * @date 2024-05-17
 */
@Slf4j
@Service
public class FsUserCourseVideoServiceImpl implements IFsUserCourseVideoService
{
    private static final Logger logger = LoggerFactory.getLogger(FsUserCourseVideoServiceImpl.class);


    private static final String miniappRealLink = "/pages_course/video.html?course=";
    private static final String REAL_LINK_PREFIX = "/courseH5/pages/course/learning?course=";
    private static final String SHORT_LINK_PREFIX = "/courseH5/pages/course/learning?s=";
    @Autowired
    private CompanyMoneyLogsMapper moneyLogsMapper;
    @Autowired
    private FsUserCourseVideoMapper fsUserCourseVideoMapper;
    @Autowired
    private IFsUserService fsUserService;
    @Autowired
    private FsUserCourseCompanyUserTimeMapper companyUserTimeMapper;
    @Autowired
    private RocketMQTemplate rocketMQTemplate;
    @Autowired
    private FsUserCourseStudyLogMapper courseStudyLogMapper;

    @Autowired
    private FsUserCourseOrderMapper fsUserCourseOrderMapper;

    @Autowired
    private FsCourseQuestionBankMapper courseQuestionBankMapper;
    @Autowired
    private FsCourseWatchLogMapper courseWatchLogMapper;
    @Autowired
    private ISopUserLogsInfoService iSopUserLogsInfoService;
    @Autowired
    private FsCourseLinkMapper fsCourseLinkMapper;


    @Autowired
    private QwExternalContactMapper qwExternalContactMapper;
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private FsCourseSopLogsMapper courseSopLogsMapper;
    @Autowired
    private QwApiService qwApiService;
    //    @Autowired
//    private IAdHtmlClickLogService adHtmlClickLogService;
    @Autowired
    private QwUserMapper qwUserMapper;
    @Autowired
    private FsUserCourseVideoRedPackageMapper fsUserCourseVideoRedPackageMapper;
    @Autowired
    private FsCourseTrafficLogMapper fsCourseTrafficLogMapper;
    @Autowired
    private FsUserIntegralLogsMapper fsUserIntegralLogsMapper;
    @Autowired
    private FsUserMapper fsUserMapper;
    @Autowired
    private IFsStorePaymentService paymentService;
    @Autowired
    private FsCourseRedPacketLogMapper redPacketLogMapper;
    @Autowired
    private FsCourseFinishTempMapper fsCourseFinishTempMapper;

    @Autowired
    private QwSopLogsMapper qwSopLogsMapper;
    @Autowired
    private FsCourseLinkMapper courseLinkMapper;
    @Autowired
    RedisCache redisCache;
    @Autowired
    private ISysConfigService sysConfigService;

    @Autowired
    private CompanyUserMapper companyUserMapper;

    @Autowired
    private IFsVideoResourceService fsVideoResourceService;
    @Autowired
    private FsVideoResourceMapper fsVideoResourceMapper;

    @Autowired
    private FsUserCourseMapper fsUserCourseMapper;

    @Autowired
    private FsUserCoursePeriodMapper fsUserCoursePeriodMapper;

    @Autowired
    private FsUserCoursePeriodDaysMapper fsUserCoursePeriodDaysMapper;

    @Autowired
    private FsUserCompanyUserMapper fsUserCompanyUserMapper;

    @Autowired
    private IQwExternalContactService qwExternalContactService;
    @Autowired
    private IQwCompanyService iQwCompanyService;
    @Autowired
    private CompanyMapper companyMapper;
    @Autowired
    private IFsUserWxService fsUserWxService;


    /**
     * 查询课堂视频
     *
     * @param videoId 课堂视频主键
     * @return 课堂视频
     */
    @Override
    public FsUserCourseVideo selectFsUserCourseVideoByVideoId(Long videoId)
    {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(videoId);
    }

    @Override
    public FsUserCourseVideoQVO selectFsUserCourseVideoByVideoIdVO(Long videoId) {
        FsUserCourseVideoQVO fsUserCourseVideoQVO=new FsUserCourseVideoQVO();
        FsUserCourseVideo courseVideo = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(videoId);

        BeanCopyUtils.copy(courseVideo,fsUserCourseVideoQVO);
        if (courseVideo.getRedPacketMoney()!=null){
            fsUserCourseVideoQVO.setRedPacketMoney(courseVideo.getRedPacketMoney().toString());
        }
        if (StringUtils.isNotEmpty(courseVideo.getQuestionBankId())){
            List<FsCourseQuestionBank> fsCourseQuestionBanks = courseQuestionBankMapper.selectFsCourseQuestionBankByIdVO(courseVideo.getQuestionBankId().split(","));
            fsUserCourseVideoQVO.setQuestionBankList(fsCourseQuestionBanks);
        }
        return fsUserCourseVideoQVO;
    }

    /**
     * 查询课堂视频列表
     *
     * @param fsUserCourseVideo 课堂视频
     * @return 课堂视频
     */
    @Override
    public List<FsUserCourseVideo> selectFsUserCourseVideoList(FsUserCourseVideo fsUserCourseVideo)
    {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoList(fsUserCourseVideo);
    }

    /**
     * 新增课堂视频
     *
     * @param fsUserCourseVideo 课堂视频
     * @return 结果
     */
    @Override
    public int insertFsUserCourseVideo(FsUserCourseVideo fsUserCourseVideo)
    {
        fsUserCourseVideo.setCreateTime(DateUtils.getNowDate());
        return fsUserCourseVideoMapper.insertFsUserCourseVideo(fsUserCourseVideo);
    }

    /**
     * 修改课堂视频
     *
     * @param fsUserCourseVideo 课堂视频
     * @return 结果
     */
    @Override
    public int updateFsUserCourseVideo(FsUserCourseVideo fsUserCourseVideo)
    {
        fsUserCourseVideo.setUpdateTime(DateUtils.getNowDate());
        return fsUserCourseVideoMapper.updateFsUserCourseVideo(fsUserCourseVideo);
    }

    /**
     * 批量删除课堂视频
     *
     * @param videoIds 需要删除的课堂视频主键
     * @return 结果
     */
    @Override
    public int deleteFsUserCourseVideoByVideoIds(String[] videoIds)
    {
        return fsUserCourseVideoMapper.deleteFsUserCourseVideoByVideoIds(videoIds);
    }

    /**
     * 删除课堂视频信息
     *
     * @param videoId 课堂视频主键
     * @return 结果
     */
    @Override
    public int deleteFsUserCourseVideoByVideoId(String videoId)
    {
        return fsUserCourseVideoMapper.deleteFsUserCourseVideoByVideoId(videoId);
    }

    @Override
    public List<FsUserCourseVideo> selectFsUserCourseVideoListByCourseId(FsUserCourseVideo fsUserCourseVideo) {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoListByCourseId(fsUserCourseVideo);
    }

    @Override
    public List<FsUserCourseVideoListUVO> selectFsUserCourseVideoListUVOByCourseId(FsUserCourseVideoListUParam param) {
        List<FsUserCourseVideoListUVO> list;
        if (param == null || param.getUserId() == null) {
            list = fsUserCourseVideoMapper.selectFsUserCourseVideoListByCourseIdAll(param);

            // 判断是否对前两条记录设置 isVip
            if (!list.isEmpty()) {
                list.stream()
                        .filter(video -> video.getCourseSort() == 1 || video.getCourseSort() == 2)
                        .forEach(video -> video.setIsVip(0));
            }
        } else {
            list = fsUserCourseVideoMapper.selectFsUserCourseVideoListUVOByCourseId(param);
            FsUserCourseOrder order = fsUserCourseOrderMapper.selectFsUserCourseOrderByCourse(param.getUserId(),param.getCourseId());
            if (order!=null&&order.getCreateType()==1){
                list.forEach(item -> item.setIsBuy(1));
            }
            for (FsUserCourseVideoListUVO videoListUVO : list) {
                FsUserCourseStudyLog studyLog = courseStudyLogMapper.selectFsUserCourseStudyLogByUser(param.getUserId(), videoListUVO.getVideoId());
                if (studyLog != null) {
                    videoListUVO.setStudyTime(studyLog.getCurrentTimes());
                    videoListUVO.setTotalTimes(studyLog.getTotalTimes());
                }
            }
            if (!list.isEmpty()) {
                list.stream()
                        .filter(video -> video.getCourseSort() == 1 || video.getCourseSort() == 2)
                        .forEach(video -> {
                            video.setIsVip(0);
                            video.setIsBuy(1);
                        });
            }

        }
        for (FsUserCourseVideoListUVO listUVO : list){
            if (StringUtils.isNotEmpty(listUVO.getPackageJson())){
                List<CoursePackageDTO> packageDTOS = JSON.parseArray(listUVO.getPackageJson(),CoursePackageDTO.class);
                for (CoursePackageDTO packageDTO : packageDTOS){
                    // 将时间按 ":" 分割
                    String[] parts = packageDTO.getDuration().split(":");
                    // 提取小时和分钟
                    int hours = Integer.parseInt(parts[0]);
                    int minutes = Integer.parseInt(parts[1]);
                    // 转换为秒
                    int seconds = hours * 3600 + minutes * 60;
                    packageDTO.setDuration(String.valueOf(seconds));
                }
                listUVO.setPackageJson(JSON.toJSONString(packageDTOS));
            }

        }
        return list;

    }

    @Override
    public Long selectCourseVideoSort(Long courseId) {
        if (fsUserCourseVideoMapper.selectCourseVideoSort(courseId)!=null){
            Long lastSort =  fsUserCourseVideoMapper.selectCourseVideoSort(courseId)+1;
            return lastSort;
        }
        return 1L;
    }

    @Override
    public R updateWatchDuration(FsUserCourseVideoFinishUParam param) {
        //临时短链不做记录
        if (param.getLinkType()!=null && param.getLinkType()==1){
            return R.ok();
        }

        if (param.getIsRoom()!=null&&param.getIsRoom()==1&&param.getQwExternalId()==null){
            return R.ok();
        }

        // 从Redis中获取观看时长
        String redisKey = "h5user:watch:duration:" + param.getQwUserId()+ ":" + param.getQwExternalId() + ":" + param.getVideoId();
//        log.info("看课redis-key：{}", redisKey);
        try {
            String durationStr = redisCache.getCacheObject(redisKey);
            Long duration = durationStr != null ? Long.parseLong(durationStr) : 0L;

            // 更新Redis中的观看时长
            if (param.getDuration() != null && param.getDuration() > duration) {
                //24小时过期
                redisCache.setCacheObject(redisKey, param.getDuration().toString(),2,TimeUnit.HOURS);
            }
            updateHeartbeat(param);
            return R.ok();
        }catch (Exception e){
            e.printStackTrace();
            logger.error("更新时长失败：{}",redisKey,e.getMessage());
            return R.error();
        }

    }

    //更新心跳时间
    public void updateHeartbeat(FsUserCourseVideoFinishUParam param) {
        String redisKey = "h5user:watch:heartbeat:" + param.getQwUserId()+ ":" + param.getQwExternalId() + ":" + param.getVideoId();
        redisCache.setCacheObject(redisKey, LocalDateTime.now().toString());
        // 设置 Redis 记录的过期时间（例如 5 分钟）
        redisCache.expire(redisKey, 300, TimeUnit.SECONDS);
    }

    @Override
    public R isAddKf(FsUserCourseVideoAddKfUParam param) {
        logger.info("zyp \n【判断添加客服】：{}",param);
        //查询用户
        FsUser fsUser = fsUserMapper.selectFsUserByUserId(param.getUserId());
        //用户不存在唤起重新授权
        if (fsUser==null){
            return R.error(504,"未授权");
        }

        String msg = "<div style=\"color: red;margin-bottom: 15px;font-weight: bold;\">本课程为会员独享<br>请长按二维码</div>\n" +
                "\t\t\t\t\t<div style=\"color: #999;font-size: 14px;font-weight: bold;\">添加伴学助手免费领取会员权限</div>";
        try {
            new Thread(() -> {
                try {
                    rocketMQTemplate.syncSend("repeat-upload", JSON.toJSONString(RepeatUploadVo.builder().type(1).fsUserId(param.getUserId()).build()));
                }catch (Exception e){
                    logger.error("看课重粉提交mq失败", e);
                }
            }).start();
        }catch (Exception e){
            logger.error("看课重粉提交mq失败", e);
        }

        Integer isRoom = param.getIsRoom();

        // 处理逻辑
        if (isRoom == null || isRoom == 0) {
            // 当 isRoom 为 null 或 0 时走 handleExt
            return handleExt(param,msg);
        } else if (isRoom == 1) {
            // 当 isRoom 为 1 时走 handleRoom
            return handleRoom(param,fsUser);
        } else {
            // 非法参数
            logger.warn("非法参数 isRoom: {}", isRoom);
            return R.error("参数错误！");
        }

    }

    private R handleRoom(FsUserCourseVideoAddKfUParam param,FsUser user) {
        //查询客户列表
        List<QwExternalContact> contacts = qwExternalContactMapper.selectQwExternalContactListVOByfsUserId(user.getUserId());
        log.info("查出来的企微客户数量："+contacts.size());
        if (!contacts.isEmpty()){
            //找出对应销售匹配的客户
            QwExternalContact matchedContact = contacts.stream()
                    .filter(contact -> contact.getQwUserId().equals(Long.parseLong(param.getQwUserId())))
                    .findFirst()
                    .orElse(null);

            if (matchedContact!=null){
                log.info("匹配到的第一个企微用户："+matchedContact.getUserId());
                log.info("企微id："+matchedContact.getId());
                log.info("用户："+param.getVideoId());
                log.info("企微用户："+param.getQwUserId());
                param.setQwExternalId(matchedContact.getId());
                FsCourseWatchLog log = courseWatchLogMapper.getWatchCourseVideoByExt(matchedContact.getId(), param.getVideoId(),param.getQwUserId());
                if (log==null){
                    createWatchLog(param);
                }
                return R.error(567,"群聊通用链接").put("qwExternalId", matchedContact.getId());
            }
        }

        String msg = "<div style=\"color: red;margin-bottom: 15px;font-weight: bold;\">本课程为群会员独享<br>请长按二维码</div>\n" +
                "\t\t\t\t\t<div style=\"color: #999;font-size: 14px;font-weight: bold;\">添加伴学助手免费领取会员权限</div>";

        return addCustomerService(param.getQwUserId(),msg);

//        QwGroupChatDetailsResult result = qwApiService.groupChatDetails(courseLink.getChatId(), param.getCorpId());
//        if(result.getErrCode() != 0){
//            log.info("企微接口请求失败，请联系管理员：" +result.getErrMsg());
//            return R.error("不是此群成员");
//        }
//        List<QwGroupChatDetailsResult.Member> collect = result.getGroupChat().getMemberList().stream().filter(e -> e.getType() == 2).collect(Collectors.toList());
//        if(collect.isEmpty()){
//            logger.info("群聊里面为空弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId());
//            return addCustomerService(param.getQwUserId(),msg);
//        }
//        Optional<QwGroupChatDetailsResult.Member> optional = collect.stream().filter(e -> e.getName().equals(user.getNickName()) || e.getName().equals(param.getNickName())).findFirst();
//        if(!optional.isPresent()){
//            logger.info("昵称未匹配上弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId());
//
//            return addCustomerService(param.getQwUserId(),msg);
//        }
//        QwGroupChatDetailsResult.Member member = optional.get();
//        QwExternalContact qwExternalContact = qwExternalContactMapper.selectOne(new QueryWrapper<QwExternalContact>().eq("user_id", result.getGroupChat().getOwner()).eq("external_user_id", member.getUserId()));
//        if(qwExternalContact==null){
//            logger.info("外部联系人为空弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId()+":"+member.getUserId()+param.getNickName());
//            return addCustomerService(param.getQwUserId(),msg);
//        }
//        Long qwExternalId = qwExternalContact.getId();
//        log.info("外部联系人数据：{}", qwExternalContact);
////        addCompanyCompanyFsUser(param);
//        FsCourseWatchLog log = courseWatchLogMapper.getWatchCourseVideoByExt(qwExternalId, param.getVideoId(),param.getQwUserId());
//        if (log==null ){
//            logger.info("看课记录为空弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId()+qwExternalId+":"+param.getVideoId()+":"+param.getQwUserId());
//            return addCustomerService(param.getQwUserId(),msg);
//        }
//        //判断外部联系人有没有绑定userId
//        if (qwExternalContact.getFsUserId()!=null){
//            //有客户有小程序id  但 登录的小程序id和根据外部联系人id查出来的小程序id不一致
//            if (!qwExternalContact.getFsUserId().equals(param.getUserId())) {
//                logger.info("小程序id不一致空弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId());
//                return addCustomerService(param.getQwUserId(),msg);
//            }
//            List<QwExternalContact> qwExternalContacts = qwExternalContactMapper.selectQwExternalContactByMiniUserId(param.getUserId());
//            //匹配客户公司id
//            if (qwExternalContacts.stream().noneMatch(contact -> contact.getCorpId().equals(param.getCorpId()))){
//                logger.info("未匹配上公司空弹二维码："+param.getCorpId()+":"+param.getQwUserId()+":"+param.getChatId()+":"+param.getUserId());
//                return addCustomerService(param.getQwUserId(),msg);
//            }
//
//            //看课记录中userId为0绑定userId
//            if (log.getUserId()==null||log.getUserId().equals(0L) || !log.getUserId().equals(param.getUserId())){
//                log.setUserId(param.getUserId());
//            }
//
//            log.setUpdateTime(new Date());
//            courseWatchLogMapper.updateFsCourseWatchLog(log);
//
//            iSopUserLogsInfoService.updateSopUserInfoByExternalId(qwExternalId,param.getUserId());
//        }else {
//            //没绑定fsUser直接绑定fsUser
//            QwExternalContact contact = new QwExternalContact();
//            contact.setId(qwExternalId);
//            contact.setFsUserId(param.getUserId());
//            qwExternalContactMapper.updateQwExternalContact(contact);
//            FsUser fsUser = new FsUser();
//            fsUser.setUserId(user.getUserId());
//            fsUser.setIsAddQw(1);
//            fsUserMapper.updateFsUser(fsUser);
//            //绑定上之后 更新观看记录
//            //看课记录中userId为0绑定userId
//            log.setUserId(param.getUserId());
//            log.setUpdateTime(new Date());
//            courseWatchLogMapper.updateFsCourseWatchLog(log);
//        }
//
//        return R.error(567,"群聊通用链接").put("qwExternalId", qwExternalContact.getId());
    }

    private void createWatchLog(FsUserCourseVideoAddKfUParam param) {
        FsCourseWatchLog log = new FsCourseWatchLog();
        BeanUtils.copyProperties(param,log);
        log.setQwExternalContactId(param.getQwExternalId());
        log.setSendType(2);
        log.setUserId(param.getUserId());
        log.setVideoId(param.getVideoId());
        log.setDuration(0L);
        log.setQwUserId(Long.parseLong(param.getQwUserId()));
        log.setCreateTime(new Date());
        log.setLogType(3);
        logger.info("zyp \n【群聊生成看课记录】:{}",param);
        courseWatchLogMapper.insertFsCourseWatchLog(log);
    }

    private R handleExt(FsUserCourseVideoAddKfUParam param,String msg){
        if (param.getLinkType()!=null&&param.getLinkType()==1){
            if (param.getLinkId()!=null){
                // 从数据库中查找短链对应的真实链接
                FsCourseLink courseLink = courseLinkMapper.selectFsCourseLinkByLinkId(param.getLinkId());
                if (courseLink != null) {
                    // 获取当前时间
                    Date currentTime = new Date();
                    // 获取链接的更新时间（假设这个字段代表过期时间）
                    Date updateTime = courseLink.getUpdateTime();

                    // 判断是否过期
                    if (currentTime.after(updateTime)) {
                        // 链接已过期
                        return R.error("链接已过期");
                    }else {
                        return R.ok();
                    }
                }
            }
            return R.error("链接过期");
        }

        Long qwExternalId = param.getQwExternalId();

        FsCourseWatchLog log=new FsCourseWatchLog();

        //如果是官方的则查真正的外部联系人id
        if (param.getLinkType()!=null&&param.getLinkType()==5) {
            log = courseWatchLogMapper.selectFsCourseWatchLogByCourseSopIdAndVideoId(param.getUserId(), param.getVideoId(), param.getQwUserId());
            if (log == null) {
                return addCustomerService(param.getQwUserId(), msg);
            }else {
                qwExternalId=log.getQwExternalContactId();
            }

        }else {
            log = courseWatchLogMapper.getWatchCourseVideoByExt(qwExternalId, param.getVideoId(),param.getQwUserId());
            if (log==null ){
                return addCustomerService(param.getQwUserId(),msg);
            }
        }

//        FsCourseWatchLog log = courseWatchLogMapper.getWatchCourseVideoByExt(param.getQwExternalId(), param.getVideoId(),param.getQwUserId());
//        if (log==null ){
//            return addCustomerService(param.getQwUserId(),msg);
//        }

        //查询是否有添加客服
        QwExternalContact externalContact = qwExternalContactMapper.selectQwExternalContactById(qwExternalId);

        //用小程序id查询外部联系人
        List<QwExternalContact> qwExternalContacts = qwExternalContactMapper.selectQwExternalContactByMiniUserId(param.getUserId());


        //如果查不出来客户信息，加好友
        if(externalContact==null){
            return addCustomerService(param.getQwUserId(),msg);
        }

        //判断外部联系人有没有绑定userId
        if (externalContact.getFsUserId()!=null){
            //有客户有小程序id  但 登录的小程序id和根据外部联系人id查出来的小程序id不一致
            if (!externalContact.getFsUserId().equals(param.getUserId())) {
                return addCustomerService(param.getQwUserId(),msg);
            }
            //匹配客户公司id
            if (qwExternalContacts.stream().noneMatch(contact -> contact.getCorpId().equals(param.getCorpId()))){
                return addCustomerService(param.getQwUserId(),msg);
            }

            //看课记录中userId为0绑定userId
            if (log.getUserId()==null||log.getUserId().equals(0L) || !log.getUserId().equals(param.getUserId())){
                log.setUserId(param.getUserId());
            }
            log.setUpdateTime(new Date());
            courseWatchLogMapper.updateFsCourseWatchLog(log);


            iSopUserLogsInfoService.updateSopUserInfoByExternalId(qwExternalId,param.getUserId());


            if (param.getLinkType()!=null&&param.getLinkType()==5){
                FsCourseLink fsCourseLink = fsCourseLinkMapper.selectExpireLinkByQwExternalId(param.getQwUserId(), param.getVideoId(), qwExternalId);
                return R.error(566,"官方群发通用链接").put("courseLink",fsCourseLink);
            }

            return R.ok();

        }else {
            //没绑定fsUser直接绑定fsUser
            QwExternalContact contact = new QwExternalContact();
            contact.setId(param.getQwExternalId());
            contact.setFsUserId(param.getUserId());
            qwExternalContactMapper.updateQwExternalContact(contact);

            iSopUserLogsInfoService.updateSopUserInfoByExternalId(qwExternalId,param.getUserId());

            FsUser user = new FsUser();
            user.setUserId(param.getUserId());
            user.setIsAddQw(1);
            user.setQwExtId(param.getQwExternalId());
            fsUserMapper.updateFsUser(user);

            iSopUserLogsInfoService.updateSopUserInfoByExternalId(qwExternalId,param.getUserId());

            //绑定上之后 更新观看记录
            //看课记录中userId为0绑定userId
            if (log.getUserId()==null||log.getUserId().equals(0L) || !log.getUserId().equals(param.getUserId())){
                log.setUserId(param.getUserId());
            }

            log.setUpdateTime(new Date());
            courseWatchLogMapper.updateFsCourseWatchLog(log);

            if (param.getLinkType()!=null&&param.getLinkType()==5){
                FsCourseLink fsCourseLink = fsCourseLinkMapper.selectExpireLinkByQwExternalId(param.getQwUserId(), param.getVideoId(), qwExternalId);
                return R.error(566,"官方群发通用链接").put("courseLink",fsCourseLink);
            }

            return R.ok();
        }
    }

    private R addCustomerService(String qwUserById,String msg){
        String contactWay = "";
        QwUser qwUser = qwUserMapper.selectQwUserById(Long.parseLong(qwUserById));
        if (qwUser==null){
            return R.error("客服不存在");
        }
        if (StringUtils.isNotEmpty(qwUser.getContactWay())){
            contactWay = qwUser.getContactWay();
        }
        else {
            String qwUserId = "[\"" + qwUser.getQwUserId() + "\"]";
            List<String> users = JSON.parseArray(qwUserId, String.class);
            QwAddContactWayParam qwAddContactWayParam = new QwAddContactWayParam();
            qwAddContactWayParam.setType(1);
            qwAddContactWayParam.setScene(2);
            qwAddContactWayParam.setUser(users);
            qwAddContactWayParam.setSkip_verify(true);
            QwAddContactWayResult qwAddContactWayResult = qwApiService.addContactWay(qwAddContactWayParam, qwUser.getCorpId());
            if (qwAddContactWayResult.getErrcode() == 0) {
                qwUser.setContactWay(qwAddContactWayResult.getQr_code());
                qwUser.setConfigId(qwAddContactWayResult.getConfig_id());
                qwUserMapper.updateQwUser(qwUser);
                contactWay = qwUser.getContactWay();
            } else {
                return R.error("请联系管理员>>>"+qwAddContactWayResult.getErrmsg());
            }
        }
        return R.error(400,msg).put("qrcode",contactWay);
    }

    @Override
    public List<FsUserCourseVideoVO> selectFsUserCourseVideoListByCourseIdAndCompany(FsUserCourseVideoParam fsUserCourseVideo) {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoListByCourseIdAndCompany(fsUserCourseVideo);
    }

    @Override
    public R updateFsUserCourseVideoCompanyRedPacket(FsUserCourseVideoParam fsUserCourseVideo) {
        fsUserCourseVideoRedPackageMapper.insertOrUpdateFsUserCourseVideoRedPackage(fsUserCourseVideo);
        return R.ok();
    }


    @Transactional
    @Override
    public R getInternetTraffic(FsUserCourseVideoFinishUParam param) {
        try {
            if (param.getBufferRate()==null){
                logger.error("zyp \n【缓冲值空】参数: {}",param);
                return R.error("缓冲值空");
            }
            FsCourseTrafficLog trafficLog = new FsCourseTrafficLog();
            trafficLog.setQwExternalContactId(param.getQwExternalId());
            trafficLog.setCreateTime(new Date());
            BeanUtils.copyProperties(param, trafficLog);

            FsUserCourseVideo video = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(param.getVideoId());
            if (video == null) {
                return R.error("视频不存在");
            }

            // 计算流量
            BigDecimal result = param.getBufferRate().divide(new BigDecimal("100"), 4, RoundingMode.HALF_UP);
            BigDecimal longAsBigDecimal = BigDecimal.valueOf(video.getFileSize());
            long roundedResult = result.multiply(longAsBigDecimal).setScale(0, RoundingMode.HALF_UP).longValue();
            trafficLog.setInternetTraffic(roundedResult);

            // 处理 UUID 为空的情况
            if (StringUtils.isNotEmpty(trafficLog.getUuId())) {
                // 直接插入或更新
//                logger.error("zyp \n【插入或更新流量】：{}",trafficLog);
                fsCourseTrafficLogMapper.insertOrUpdateTrafficLog(trafficLog);
            }
        } catch (Exception e) {
            e.printStackTrace();
            // 打印参数param和异常信息
            logger.error("zyp \n【插入或更新流量失败】参数: {}, 错误信息：{}", param, e.getMessage(), e);
            return R.error();
        }
        return R.ok();
    }


    @Override
    public R getIntegralByH5Video(FsUserCourseVideoFinishUParam param) {
//        //临时短链不做处理
//        if (param.getLinkType()!=null&&param.getLinkType()==1){
//            return R.ok();
//        }
//        FsCourseWatchLog log = courseWatchLogMapper.getWatchCourseVideo(param.getUserId(),param.getVideoId(),param.getQwUserId(), param.getQwExternalId());
//        if (log==null){
//            return R.error("无记录");
//        }
//        if (log.getLogType()==2){
//            return R.error("已存在完课记录");
//        }
//        if (log.getLogType()==1){
//            FsUserCourseVideo video = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(param.getVideoId());
//            if (video==null){
//                return R.error("课程视频不存在！");
//            }
//            FsUser user = fsUserMapper.selectFsUserByUserId(param.getUserId());
//            if (user!=null){
//                //判断该视频可增加积分的此时 （每十分钟增加积分）
//                Long count = video.getDuration()/600;
//                Long getIntegralCount = fsUserIntegralLogsMapper.selectH5VideoIntegralCount(param.getUserId(), param.getVideoId());
//                if (getIntegralCount.equals(count)){
//                    return R.error("该课堂或积分已达限制！");
//                }
//                String json = configService.selectConfigByKey("course.config");
//                CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);
//                //增加积分
//                FsUser userMap=new FsUser();
//                userMap.setUserId(user.getUserId());
//                userMap.setIntegral(user.getIntegral()+config.getVideoIntegral());
//                fsUserMapper.updateFsUser(userMap);
//                FsUserIntegralLogs integralLogs = new FsUserIntegralLogs();
//                integralLogs.setIntegral(config.getVideoIntegral().longValue());
//                integralLogs.setUserId(user.getUserId());
//                integralLogs.setBalance(userMap.getIntegral());
//                integralLogs.setLogType(16);
//                integralLogs.setBusinessId(log.getLogId().toString());
//                integralLogs.setCreateTime(new Date());
//                fsUserIntegralLogsMapper.insertFsUserIntegralLogs(integralLogs);
//
//                FsCourseRedPacketLog redPacketLog = new FsCourseRedPacketLog();
//                redPacketLog.setCourseId(log.getCourseId());
//                redPacketLog.setOutBatchNo(integralLogs.getId().toString());
//                redPacketLog.setCompanyId(log.getCompanyId());
//                redPacketLog.setUserId(log.getUserId());
//                redPacketLog.setVideoId(log.getVideoId());
//                redPacketLog.setStatus(1);
//                redPacketLog.setQwUserId(log.getQwUserId() != null ? log.getQwUserId() : null );
//                redPacketLog.setCompanyUserId(log.getCompanyUserId());
//                redPacketLog.setCreateTime(new Date());
//                redPacketLog.setAmount(BigDecimal.valueOf(config.getVideoIntegral()).divide(BigDecimal.valueOf(1000)));
//                redPacketLog.setRemark("点播看课获得积分转");
//                redPacketLog.setWatchLogId(log.getLogId() !=null ? log.getLogId() : null);
//                redPacketLogMapper.insertFsCourseRedPacketLog(redPacketLog);
//                return R.ok();
//            }
//        }
        return R.error();
    }


    @Override
    @Transactional
    public R sendReward(FsCourseSendRewardUParam param) {
        // 获取用户信息
        FsUser user = fsUserMapper.selectFsUserByUserId(param.getUserId());
//        if (StringUtils.isEmpty(user.getMpOpenId())){
//            return R.error("未识别到领取信息");
//        }
        FsCourseWatchLog log = new FsCourseWatchLog();

        // 根据链接类型判断是否已发放奖励
        log = courseWatchLogMapper.getWatchCourseVideo(param.getUserId(), param.getVideoId(), param.getQwUserId(), param.getQwExternalId());
        if (log == null) {
            return R.error("无记录");
        }
        if (log.getRewardType() != null) {
            FsCourseRedPacketLog packetLog = redPacketLogMapper.selectFsCourseRedPacketLogByTemporary(param.getVideoId(), param.getUserId());
            if(packetLog != null && packetLog.getStatus() == 1) {
                return R.error("奖励已发放");
            }
            if(packetLog != null && packetLog.getStatus() == 0) {
                if(StringUtils.isNotEmpty(packetLog.getResult())){
                    R r = JSON.parseObject(packetLog.getResult(), R.class);
                    return r;
                } else {
                    return R.error("奖励已发放");
                }
            }
            if(packetLog != null && packetLog.getStatus() == 2) {
                return R.error("请联系客服补发");
            }
            return R.error("奖励已发放");
        }
        // 获取视频信息
        FsUserCourseVideo video = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(param.getVideoId());

        // 获取配置信息
        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);

        // 根据奖励类型发放不同奖励
        switch (config.getRewardType()) {
            // 红包奖励
            case 1:
                return sendRedPacketReward(param, user, log, video, config);
            // 积分奖励
            case 2:
                return sendIntegralReward(param,user, log, config);
            default:
                return R.error("参数错误！");
        }
    }

    @Override
    public R sendRewardByFsUser(FsCourseSendRewardUParam param) {
        FsUser user = fsUserMapper.selectFsUserByUserId(param.getUserId());
        if (user == null){
            return R.error("未识别到用户信息");
        }
        FsCourseWatchLog log = courseWatchLogMapper.getWatchCourseVideoByFsUser(param.getUserId(), param.getVideoId(), param.getCompanyUserId());
        if (log == null) {
            return R.error("无记录");
        }
        if (log.getRewardType() != null) {
            FsCourseRedPacketLog fsCourseRedPacketLog = redPacketLogMapper.selectUserFsCourseRedPacketLog(param.getVideoId(), param.getUserId(),param.getPeriodId());
            if(fsCourseRedPacketLog != null && fsCourseRedPacketLog.getStatus() == 1) {
                return R.error("奖励已发放");
            }
            if(fsCourseRedPacketLog != null && fsCourseRedPacketLog.getStatus() == 0) {
                if(StringUtils.isNotEmpty(fsCourseRedPacketLog.getResult())){
                    R r = JSON.parseObject(fsCourseRedPacketLog.getResult(), R.class);
                    return r;
                } else {
                    return R.error();
                }
            }
        }


        // 获取视频信息
        FsUserCourseVideo video = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(param.getVideoId());

        // 获取配置信息
        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);

        // 根据奖励类型发放不同奖励
        switch (config.getRewardType()) {
            // 红包奖励
            case 1:
                return sendRedPacketReward(param, user, log, video, config);
            // 积分奖励
            case 2:
                return sendIntegralReward(param,user, log, config);
            default:
                return R.error("参数错误！");
        }
    }

    /**
     * 发放红包奖励
     *
     * @param param 请求参数
     * @param user 用户信息
     * @param log 观看日志
     * @param video 视频信息
     * @param config 配置信息
     * @return 处理结果
     */
    private R sendRedPacketReward(FsCourseSendRewardUParam param, FsUser user, FsCourseWatchLog log, FsUserCourseVideo video, CourseConfig config) {
        // 判断是否属于领取红包时间（会员看课发放红包）
        if (param.getPeriodId()!=null && param.getPeriodId()>0) {
            FsUserCoursePeriodDays periodDays = new FsUserCoursePeriodDays();
            periodDays.setVideoId(param.getVideoId());
            periodDays.setPeriodId(param.getPeriodId());
            //正常情况是只能查询到一条，之前可能存在重复的脏数据，暂使用查询list的方式
            List<FsUserCoursePeriodDays> fsUserCoursePeriodDays = fsUserCoursePeriodDaysMapper.selectFsUserCoursePeriodDaysList(periodDays);
            if(fsUserCoursePeriodDays != null && !fsUserCoursePeriodDays.isEmpty()){
                periodDays = fsUserCoursePeriodDays.get(0);
            }
            if(periodDays != null && periodDays.getLastJoinTime() !=null && LocalDateTime.now().isAfter(periodDays.getLastJoinTime())) {
                return R.error(403,"已超过领取红包时间");
            }
        }




        // 确定红包金额
        BigDecimal amount = BigDecimal.ZERO;
        FsUserCourseVideoRedPackage redPackage = fsUserCourseVideoRedPackageMapper.selectRedPacketByCompanyId(param.getVideoId(), param.getCompanyId(), param.getPeriodId());

        if (redPackage != null) {
            amount = redPackage.getRedPacketMoney();
        } else if (video != null) {
            amount = video.getRedPacketMoney();
        }

        // 准备发送红包参数
        WxSendRedPacketParam packetParam = new WxSendRedPacketParam();
//        packetParam.setOpenId(getOpenId(user.getUserId(), param.getCompanyId(), param.getSource()));
        packetParam.setOpenId(user.getMpOpenId());
        // 来源是小程序切换openId
        if (param.getSource() == 2) {
            System.out.println("小程序id"+user.getCourseMaOpenId());
            packetParam.setOpenId(user.getCourseMaOpenId());
        }
        packetParam.setAmount(amount);
        packetParam.setSource(param.getSource());
        packetParam.setRedPacketMode(config.getRedPacketMode());
        packetParam.setCompanyId(param.getCompanyId());

        System.out.println("红包金额"+amount);
        System.out.println("红包商户号"+packetParam);
        //2025.6.19 红包金额为0的时候
        if (amount.compareTo(BigDecimal.ZERO)>0){

            Company company = companyMapper.selectCompanyByIdForUpdate(param.getCompanyId());
            BigDecimal money = company.getMoney();
            BigDecimal subtract = money.subtract(amount);
            if (subtract.compareTo(BigDecimal.ZERO)<0){
                FsCourseRedPacketLog redPacketLog = new FsCourseRedPacketLog();
                redPacketLog.setCourseId(param.getCourseId());
                redPacketLog.setCompanyId(param.getCompanyId());
                redPacketLog.setUserId(param.getUserId());
                redPacketLog.setVideoId(param.getVideoId());
                redPacketLog.setStatus(2);
                redPacketLog.setQwUserId(param.getQwUserId() != null ? param.getQwUserId() : null);
                redPacketLog.setCompanyUserId(param.getCompanyUserId());
                redPacketLog.setCreateTime(new Date());
                redPacketLog.setAmount(amount);
                redPacketLog.setWatchLogId(log.getLogId() != null ? log.getLogId() : null);
                redPacketLog.setPeriodId(param.getPeriodId());
                redPacketLogMapper.insertFsCourseRedPacketLog(redPacketLog);
                return R.error("销售公司余额不足");
            }
            // 发送红包
            R sendRedPacket = paymentService.sendRedPacket(packetParam);
            if (sendRedPacket.get("code").equals(200)) {
                FsCourseRedPacketLog redPacketLog = new FsCourseRedPacketLog();
                TransferBillsResult transferBillsResult;
                if (sendRedPacket.get("isNew").equals(1)){
                    transferBillsResult = (TransferBillsResult)sendRedPacket.get("data");
                    redPacketLog.setResult(JSON.toJSONString(sendRedPacket));
                    redPacketLog.setOutBatchNo(transferBillsResult.getOutBillNo());
                }else {
                    redPacketLog.setOutBatchNo(sendRedPacket.get("orderCode").toString());
                }
                // 添加红包记录
                redPacketLog.setCourseId(param.getCourseId());
//            redPacketLog.setOutBatchNo(sendRedPacket.get("orderCode").toString());
                redPacketLog.setCompanyId(param.getCompanyId());
                redPacketLog.setUserId(param.getUserId());
                redPacketLog.setVideoId(param.getVideoId());
                redPacketLog.setStatus(0);
                redPacketLog.setQwUserId(param.getQwUserId() != null ? param.getQwUserId() : null);
                redPacketLog.setCompanyUserId(param.getCompanyUserId());
                redPacketLog.setCreateTime(new Date());
                redPacketLog.setAmount(amount);
                redPacketLog.setWatchLogId(log.getLogId() != null ? log.getLogId() : null);
                redPacketLog.setPeriodId(param.getPeriodId());
                redPacketLogMapper.insertFsCourseRedPacketLog(redPacketLog);

                // 更新观看记录的奖励类型
                log.setRewardType(config.getRewardType());
                courseWatchLogMapper.updateFsCourseWatchLog(log);
                company.setMoney(subtract);
                companyMapper.updateCompany(company);

                CompanyMoneyLogs logs=new CompanyMoneyLogs();
                logs.setCompanyId(company.getCompanyId());
                logs.setRemark("扣除红包金额");
                logs.setMoney(amount.multiply(new BigDecimal(-1)));
                logs.setLogsType(15);
                logs.setBalance(company.getMoney());
                logs.setCreateTime(new Date());
                moneyLogsMapper.insertCompanyMoneyLogs(logs);

                return sendRedPacket;
            } else {
                return R.error("奖励发送失败，请联系客服");
            }
        } else {
            FsCourseRedPacketLog redPacketLog = new FsCourseRedPacketLog();
            // 添加红包记录
            redPacketLog.setCourseId(param.getCourseId());
//            redPacketLog.setOutBatchNo(sendRedPacket.get("orderCode").toString());
            redPacketLog.setCompanyId(param.getCompanyId());
            redPacketLog.setUserId(param.getUserId());
            redPacketLog.setVideoId(param.getVideoId());
            redPacketLog.setStatus(0);
            redPacketLog.setQwUserId(param.getQwUserId() != null ? param.getQwUserId() : null);
            redPacketLog.setCompanyUserId(param.getCompanyUserId());
            redPacketLog.setCreateTime(new Date());
            redPacketLog.setAmount(BigDecimal.ZERO);
            redPacketLog.setWatchLogId(log.getLogId() != null ? log.getLogId() : null);
            redPacketLog.setPeriodId(param.getPeriodId());
            redPacketLogMapper.insertFsCourseRedPacketLog(redPacketLog);

            // 更新观看记录的奖励类型
//            if (param.getLinkType() == null || param.getLinkType() == 0) {
            log.setRewardType(config.getRewardType());
            courseWatchLogMapper.updateFsCourseWatchLog(log);
//            }
            return R.ok("红包发送成功");
        }

    }

    /**
     * 获取用户openId
     *
     * @param userId    用户ID
     * @param companyId 公司ID
     * @param source    来源 1公众号 2小程序
     * @return openId
     */
    private String getOpenId(Long userId, Long companyId, Integer source) {
        Company company = companyMapper.selectCompanyById(companyId);
        String appId = source == 1 ? company.getCourseMaAppId() : company.getCourseMiniAppId();

        // 公司配置为空时获取默认配置
        if (StringUtils.isBlank(appId)) {
            String json = configService.selectConfigByKey("course.config");
            CourseConfig config = JSON.parseObject(json, CourseConfig.class);
            appId = source == 1 ? config.getMpAppId() : config.getMiniprogramAppid();
        }

        // 查询openId
        Wrapper<FsUserWx> queryWrapper = Wrappers.<FsUserWx>lambdaQuery().eq(FsUserWx::getFsUserId, userId).eq(FsUserWx::getAppId, appId);
        FsUserWx fsUserWx = fsUserWxService.getOne(queryWrapper);
        if (Objects.isNull(fsUserWx)) {
            throw new CustomException("获取openId失败");
        }

        return fsUserWx.getOpenId();
    }

    /**
     * 发放积分奖励
     *
     * @param user 用户信息
     * @param log 观看日志
     * @param config 配置信息
     * @return 处理结果
     */
    private R sendIntegralReward(FsCourseSendRewardUParam param,FsUser user, FsCourseWatchLog log, CourseConfig config) {
        // 更新用户积分
        FsUser userMap = new FsUser();
        userMap.setUserId(user.getUserId());
        userMap.setIntegral(user.getIntegral() + config.getAnswerIntegral());
        fsUserMapper.updateFsUser(userMap);

        // 记录积分日志
        FsUserIntegralLogs integralLogs = new FsUserIntegralLogs();
        integralLogs.setIntegral(config.getAnswerIntegral().longValue());
        integralLogs.setUserId(user.getUserId());
        integralLogs.setBalance(userMap.getIntegral());
        integralLogs.setLogType(17);
        integralLogs.setBusinessId(StringUtils.isNotEmpty(log.getLogId().toString()) ? log.getLogId().toString() : null);
        integralLogs.setCreateTime(new Date());
        fsUserIntegralLogsMapper.insertFsUserIntegralLogs(integralLogs);

        //更新看课记录的奖励类型
        log.setRewardType(config.getRewardType());
        courseWatchLogMapper.updateFsCourseWatchLog(log);
        logger.info("发放奖励====================》看课记录,{}",log);

        //转换红包
        FsCourseRedPacketLog redPacketLog = new FsCourseRedPacketLog();
        redPacketLog.setCourseId(param.getCourseId());
        redPacketLog.setOutBatchNo(integralLogs.getId().toString());
        redPacketLog.setCompanyId(param.getCompanyId());
        redPacketLog.setUserId(param.getUserId());
        redPacketLog.setVideoId(param.getVideoId());
        redPacketLog.setStatus(1);
        redPacketLog.setQwUserId(param.getQwUserId() != null ? param.getQwUserId() : null );
        redPacketLog.setCompanyUserId(param.getCompanyUserId());
        redPacketLog.setCreateTime(new Date());
        redPacketLog.setAmount(BigDecimal.valueOf(config.getAnswerIntegral()).divide(BigDecimal.valueOf(1000)));
        redPacketLog.setRemark("点播答题领取积分转");
        redPacketLog.setWatchLogId(log.getLogId() !=null ? log.getLogId() : null);
        redPacketLogMapper.insertFsCourseRedPacketLog(redPacketLog);
        return R.ok("奖励发放成功").put("rewardType",config.getRewardType());
    }

    @Override
    public List<FsUserCourseVideoPageListVO> pageListCourseVideo(UserCourseVideoPageParam param) {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoPageList(param);
    }

    @Override
    public ResponseResult<FsUserCourseVideoDetailsVO> getVideoDetails(Long videoId) {
        FsUserCourseVideo fsUserCourseVideo = fsUserCourseVideoMapper.selectFsUserCourseVideoByVideoId(videoId);
        FsUserCourseVideoDetailsVO fsUserCourseVideoDetailsVO = new FsUserCourseVideoDetailsVO();
        BeanUtils.copyProperties(fsUserCourseVideo, fsUserCourseVideoDetailsVO);

        // 获取课程相关的题库
        String questionBankId = fsUserCourseVideo.getQuestionBankId();
        List<FsUserVideoQuestionVO> questionList = Collections.emptyList();
        if (StringUtils.isNotEmpty(questionBankId)) {
            String[] questionBankIds = questionBankId.split(",");
            List<FsCourseQuestionBank> fsCourseQuestionBanks = courseQuestionBankMapper.selectFsCourseQuestionBankByIdVO(questionBankIds);
            questionList = fsCourseQuestionBanks.stream().map(v -> {
                FsUserVideoQuestionVO fsUserVideoQuestionVO = new FsUserVideoQuestionVO();
                BeanUtils.copyProperties(v, fsUserVideoQuestionVO);
                return fsUserVideoQuestionVO;
            }).collect(Collectors.toList());
        }

        fsUserCourseVideoDetailsVO.setQuestionBankList(questionList);
        return ResponseResult.ok(fsUserCourseVideoDetailsVO);
    }

    @Autowired
    SopUserLogsInfoMapper sopUserLogsInfoMapper;

    @Override
    public R registerCourse(FsUserCourseRegisterParam param) {


        FsUser fsUser = fsUserMapper.selectFsUserById(param.getUserId());
        if (fsUser==null){
            return R.error("未登录成功");
        }
        logger.info(""+fsUser);
        if (fsUser.getIsAddQw()==1){
            return R.error("已经注册");
        }
        QwExternalContact qwExternalContact = qwExternalContactMapper.selectQwExternalContactById(param.getQwExternalId());
        if (qwExternalContact==null){
            return R.error("注册信息错误");
        }
        FsUser u = new FsUser();
        u.setUserId(param.getUserId());
        u.setIsAddQw(1);
        u.setQwExtId(param.getQwExternalId());
        fsUserMapper.updateFsUser(u);
        QwExternalContact qw = new QwExternalContact();
        qw.setFsUserId(fsUser.getUserId());
        qw.setId(qwExternalContact.getId());
        qwExternalContactMapper.updateById(qw);
        List<String> list= sopUserLogsInfoMapper.selectSopUserLogsInfoByExtId(qwExternalContact.getId());
        if (list!=null&& !list.isEmpty()){
            sopUserLogsInfoMapper.updateSopUserLogsInfoFsUserIdById(list,param.getUserId());
        }
        return R.ok();
    }

    @Override
    public List<FsUserVideoListVO> getListCourseVideo(UserCourseVideoPageParam param) {
        List<FsUserCourseVideoPageListVO> list = fsUserCourseVideoMapper.selectFsUserCourseVideoPageList(param);
        return list.stream().map(v -> {
            FsUserVideoListVO videoListVO = new FsUserVideoListVO();
            BeanUtils.copyProperties(v, videoListVO);
            return videoListVO;
        }).collect(Collectors.toList());
    }

    @Override
    @Transactional
    public ResponseResult<Boolean> isAddCompanyUser(FsUserCourseAddCompanyUserParam param) {
        logger.info("=======================进入个微-判断是否添加客服===========================，入参：{}",param);
        //查询用户
        FsUser fsUser = fsUserMapper.selectFsUserById(param.getUserId());
        if (fsUser == null){
            return ResponseResult.fail(404,"当前用户信息不存在");
        }

        //判断该销售是否存在
        CompanyUser companyUser = companyUserMapper.selectCompanyUserById(param.getCompanyUserId());
        if (companyUser == null){
            return ResponseResult.fail(405,"当前销售不存在");
        }

        //判断：1、如果没有绑定销售，就返回给客服的微信图片;
        //2、如果只绑定了当前销售，需要添加看课记录（正常流程）；
        //3、以上都不是，则标识重粉，需要加入关系表，并打上重粉标签
        if(fsUser.getCompanyUserId() == null) {
            return ResponseResult.fail(BizResponseEnum.DATA_NOT_EXIST, getCompanyUserQRCode(companyUser));
        }

        // 逻辑调整：如果会员已经绑定了销售，直接提示，不添加重粉数据了-2025年6月16日14点53分
        if (fsUser.getCompanyUserId() != null && !param.getCompanyUserId().equals(fsUser.getCompanyUserId())){
            return ResponseResult.fail(406,"该用户已成为其他销售会员");
        }

        // 如果开启了黑名单审核，需要提示
        if(fsUser.getStatus() == 0) {
            return ResponseResult.fail(505, "请微信联系您的群主~");
//            return ResponseResult.fail(BizResponseEnum.WAIT_APPROVAL,getCompanyUserQRCode(companyUser));
        }

        //查询看课记录
//        FsCourseWatchLog watchCourseVideo = courseWatchLogMapper.getWatchCourseVideoByFsUser(param.getUserId(), param.getVideoId(), param.getCompanyUserId());
        FsCourseWatchLog watchCourseVideo = courseWatchLogMapper.getCourseWatchLogByUser(param.getUserId(), param.getVideoId());
        // 获取课程所属项目id
        FsUserCourse fsUserCourse = fsUserCourseMapper.selectFsUserCourseByCourseId(param.getCourseId());
        Long courseProject = null;
        if(fsUserCourse != null){
            courseProject = fsUserCourse.getProject();
        }

        //添加判断：该用户是否已经存在此课程的看课记录，并且看课记录的销售id不是传入的销售id
        if(watchCourseVideo != null){
            if(!watchCourseVideo.getCompanyUserId().equals(param.getCompanyUserId())) {
                //提示
                return ResponseResult.fail(504, "已看过其他销售分享的此课程，不能重复观看");
            }

            FsCourseWatchLog updateLog = new FsCourseWatchLog();
            updateLog.setPeriodId(param.getPeriodId());
            updateLog.setProject(courseProject);
            updateLog.setUpdateTime(new Date());
            courseWatchLogMapper.updateFsCourseWatchLog(updateLog);
        } else {
            FsCourseWatchLog fsCourseWatchLog = new FsCourseWatchLog();
            BeanUtils.copyProperties(param, fsCourseWatchLog);
            fsCourseWatchLog.setSendType(1);
            fsCourseWatchLog.setDuration(0L);
            fsCourseWatchLog.setCreateTime(new Date());
            fsCourseWatchLog.setLogType(1);
            fsCourseWatchLog.setProject(courseProject);
            courseWatchLogMapper.insertFsCourseWatchLog(fsCourseWatchLog);

            String redisKey = "h5wxuser:watch:heartbeat:" + param.getUserId() + ":" + param.getVideoId() + ":" + param.getCompanyUserId();
            redisCache.setCacheObject(redisKey, LocalDateTime.now().toString());
            // 设置 Redis 记录的过期时间（例如 5 分钟）
            redisCache.expire(redisKey, 300, TimeUnit.SECONDS);
        }

        // 添加会员销售关系表数据
        // 逻辑调整：如果会员已经绑定了销售，直接提示，不添加重粉数据了-2025年6月16日14点58分
        FsUserCompanyUser fsUserCompanyUser = getFsUserCompanyUser(param, fsUser);
        QueryWrapper<FsUserCompanyUser> queryWrapper = new QueryWrapper<FsUserCompanyUser>().eq("user_id", param.getUserId()).eq("company_user_id", param.getCompanyUserId());
        Integer i = fsUserCompanyUserMapper.selectCount(queryWrapper);
        if(i == 0) {
            fsUserCompanyUserMapper.insertFsUserCompanyUser(fsUserCompanyUser);
        }

//        // 如果重粉需要打上重粉标签
//        if(1 == fsUserCompanyUser.getIsRepeatFans()){
//            FsUserCourseBeMemberParam fsUserCourseBeMemberParam = new FsUserCourseBeMemberParam();
//            fsUserCourseBeMemberParam.setUserId(param.getUserId());
//            fsUserCourseBeMemberParam.setCompanyId(param.getCompanyId());
//            fsUserCourseBeMemberParam.setCompanyUserId(param.getCompanyUserId());
//            fsUserService.setRepeatFansTag(fsUserCourseBeMemberParam);
//        }
        return ResponseResult.ok(Boolean.TRUE);
    }

    // 添加关系表数据
    public static FsUserCompanyUser getFsUserCompanyUser(FsUserCourseAddCompanyUserParam param, FsUser fsUser) {
        FsUserCompanyUser fsUserCompanyUser = new FsUserCompanyUser();
        // 判断是否绑定了销售，如果已绑定，则需要标识为重粉，且放黑名单
        if (fsUser.getCompanyUserId() != null && !fsUser.getCompanyUserId().equals(param.getCompanyUserId())) {
            fsUserCompanyUser.setIsRepeatFans(1);
        } else {
            fsUserCompanyUser.setIsRepeatFans(0);
        }
        fsUserCompanyUser.setUserId(param.getUserId());
        fsUserCompanyUser.setCompanyId(param.getCompanyId());
        fsUserCompanyUser.setCompanyUserId(param.getCompanyUserId());
        return fsUserCompanyUser;
    }

    private String getCompanyUserQRCode(CompanyUser companyUser) {
        String companyUserQRCode;
        if(StringUtils.isNotEmpty(companyUser.getQrCodeWeixin())){
            companyUserQRCode = companyUser.getQrCodeWeixin();
        } else {
            String json = configService.selectConfigByKey("course.config");
            CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);
            companyUserQRCode = config.getCompanyUserQRCode();
        }
        return companyUserQRCode;
    }

    @Override
    public ResponseResult<FsUserCourseVideoLinkDetailsVO> getLinkCourseVideoDetails(FsUserCourseVideoLinkParam param) {
//        FsUserCoursePeriodDays periodDays = new FsUserCoursePeriodDays();
//        periodDays.setVideoId(param.getVideoId());
//        periodDays.setPeriodId(param.getPeriodId());
//        //正常情况是只能查询到一条，之前可能存在重复的脏数据，暂使用查询list的方式
//        List<FsUserCoursePeriodDays> fsUserCoursePeriodDays = fsUserCoursePeriodDaysMapper.selectFsUserCoursePeriodDaysList(periodDays);
//        if(fsUserCoursePeriodDays != null && !fsUserCoursePeriodDays.isEmpty()){
//            periodDays = fsUserCoursePeriodDays.get(0);
//        }
//        if(periodDays.getStatus() != 1){
//            return ResponseResult.fail(403, "当前课程未开始或已结束，暂不能看课");
//        }

        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);

        // 1、获取视频详情、问题详情
        ResponseResult<FsUserCourseVideoDetailsVO> videoDetails = this.getVideoDetails(param.getVideoId());
        FsUserCourseVideoDetailsVO courseVideoDetails = videoDetails.getData() != null ? videoDetails.getData() : null;

        //课程logo
        if (param.getPeriodId()!=null){
            FsUserCoursePeriod fsUserCoursePeriod = fsUserCoursePeriodMapper.selectFsUserCoursePeriodById(param.getPeriodId());
            if (fsUserCoursePeriod!=null){
                config.setCourseLogo(fsUserCoursePeriod.getCourseLogo());
            }
        }

        long duration = 0L;
        long tipsTime = 0L;
        long tipsTime2 = 0L;
        int isFinish = 0;
        FsUserCourseVideoLinkDetailsVO vo = new FsUserCourseVideoLinkDetailsVO();
        vo.setCourseVideoDetails(courseVideoDetails);
        vo.setCourseConfig(config);
        vo.setIsFinish(isFinish);
        vo.setPlayDuration(duration);

        //2、判断链接类型
        if (param.getLinkType() != null && param.getLinkType() == 1) {
            ResponseResult.ok(vo);
        }
        // 从Redis中获取用户目前的观看时长
        String redisKey = "h5wxuser:watch:duration:" + param.getFsUserId() + ":" + param.getVideoId() + ":" + param.getCompanyUserId();
        String durationCurrent = redisCache.getCacheObject(redisKey);

        //3、获取看课记录
        FsCourseWatchLog watchLog = courseWatchLogMapper.getWatchLogByFsUser(param.getVideoId(), param.getFsUserId(), param.getCompanyUserId());
        if (durationCurrent != null) {
            duration = Long.parseLong(durationCurrent);
        } else {
            duration = Objects.isNull(watchLog) ? 0 : watchLog.getDuration();
        }
//
        if (courseVideoDetails != null && courseVideoDetails.getDuration() != null){
            tipsTime = courseVideoDetails.getDuration() / 3;
            tipsTime2 = (courseVideoDetails.getDuration() * 2) / 3;
        }
        vo.setTipsTime(tipsTime);
        vo.setTipsTime2(tipsTime2);
        //判断是否完课
        if (watchLog!=null && watchLog.getLogType() == 2) {
            isFinish = 1;
        }

        //将视频时长也存到redis
        String videoRedisKey = "h5wxuser:video:duration:" + param.getVideoId();
        Long videoDuration = redisCache.getCacheObject(videoRedisKey);
        if (videoDuration == null) {
            redisCache.setCacheObject(videoRedisKey, courseVideoDetails != null ? courseVideoDetails.getDuration() != null ? courseVideoDetails.getDuration() : 0 : 0);
        }
        vo.setIsFinish(isFinish);
        vo.setPlayDuration(duration);
        //判断营期的课程状态是否是进行中
        if(param.getId() != null){
            FsUserCoursePeriodDays days = fsUserCoursePeriodDaysMapper.selectById(param.getId());

            // 查询销售设置的看课时间
            LocalDateTime companyUserStartDateTime = null;
            LocalDateTime companyUserEndDateTime = null;

            List<CompanyUserTimeQueryParam> queryList = new ArrayList<>();
            CompanyUserTimeQueryParam query = new CompanyUserTimeQueryParam();
            query.setPeriodId(param.getPeriodId());
            query.setCourseId(param.getCourseId());
            query.setVideoId(param.getVideoId());
            query.setCompanyUserId(param.getCompanyUserId());
            queryList.add(query);
            List<FsUserCourseCompanyUserTime> fsUserCourseCompanyUserTimes = companyUserTimeMapper.batchSelectByParams(queryList);

            if(CollectionUtils.isNotEmpty(fsUserCourseCompanyUserTimes)){
                FsUserCourseCompanyUserTime fsUserCourseCompanyUserTime = fsUserCourseCompanyUserTimes.get(0);
                Date cuStartDateTime = fsUserCourseCompanyUserTime.getStartDateTime();
                Date cuEndDateTime = fsUserCourseCompanyUserTime.getEndDateTime();

                if(cuStartDateTime != null){
                    Instant instant = cuStartDateTime.toInstant();
                    ZoneId zoneId = ZoneId.systemDefault();
                    companyUserStartDateTime = instant.atZone(zoneId).toLocalDateTime();
                }

                if(cuEndDateTime != null){
                    Instant instant = cuEndDateTime.toInstant();
                    ZoneId zoneId = ZoneId.systemDefault();
                    companyUserEndDateTime = instant.atZone(zoneId).toLocalDateTime();
                }
            }
            vo.setStartDateTime(companyUserStartDateTime != null ? companyUserStartDateTime : days.getStartDateTime());
            vo.setEndDateTime(companyUserEndDateTime != null ? companyUserEndDateTime : days.getEndDateTime());
            vo.setRang(DateUtil.isWithinRangeSafe(LocalDateTime.now(),
                    companyUserStartDateTime != null ? companyUserStartDateTime : days.getStartDateTime(),
                    companyUserEndDateTime != null ? companyUserEndDateTime : days.getEndDateTime())
                    && days.getStatus() == 1);
        }
        return ResponseResult.ok(vo);
    }

    @Override
    public R addWatchLogByLink(FsUserCourseAddCompanyUserParam param) {

        return null;
    }

    @Override
    public R updateWatchDurationWx(FsUserCourseVideoUParam param) {
        //临时短链不做记录
        if (param.getLinkType() != null && param.getLinkType() == 1){
            return R.ok();
        }

        // 从Redis中获取观看时长
        String redisKey = "h5wxuser:watch:duration:" + param.getUserId() + ":" + param.getVideoId() + ":" + param.getCompanyUserId();
        log.info("看课redis缓存key：{}", redisKey);
        try {
            String durationStr = redisCache.getCacheObject(redisKey);
            log.info("看课记录：{}", durationStr);
            long duration = durationStr != null ? Long.parseLong(durationStr) : 0L;

            // 更新Redis中的观看时长
            if (param.getDuration() != null && param.getDuration() > duration) {
                //24小时过期
                redisCache.setCacheObject(redisKey, param.getDuration().toString(),2,TimeUnit.HOURS);
            }

            //更新缓存中的心跳时间
            updateHeartbeatWx(param);
            return R.ok();
        } catch (Exception e) {
            logger.error("更新看课时长失败：{}", redisKey, e.getMessage());
            return R.error("更新看课时长失败");
        }
    }

    @Override
    public void updates(CourseVideoUpdates vo) {
        fsUserCourseVideoMapper.updates(vo);
    }

    @Override
    public void batchSaveVideo(BatchVideoSvae vo) {
        List<FsVideoResource> videoResourceList = fsVideoResourceMapper.selectBatchIds(vo.getIds());
        videoResourceList = videoResourceList.stream()
                .sorted(Comparator.comparing(FsVideoResource::getSort).thenComparing(FsVideoResource::getId))
                .collect(Collectors.toList());
        FsUserCourseVideo param = new FsUserCourseVideo();
        param.setCourseId(vo.getCourseId());
        List<FsUserCourseVideo> videoList = selectFsUserCourseVideoList(param);
        AtomicLong i = new AtomicLong(videoList.size() + 1);
        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);

        List<FsUserCourseVideo> collect = videoResourceList.stream().map(e -> {
            FsUserCourseVideo entity = new FsUserCourseVideo();
            entity.setTitle(e.getResourceName());
            entity.setVideoUrl(e.getVideoUrl());
            entity.setThumbnail(e.getThumbnail());
            entity.setDuration(e.getDuration().longValue());
            entity.setCourseId(vo.getCourseId());
            entity.setStatus(3L);
            entity.setCourseSort(i.getAndIncrement());
            entity.setFileName(e.getFileName());
            entity.setQuestionBankId(e.getProjectIds());
            entity.setLineOne(e.getLine1());
            entity.setLineTwo(e.getLine2());
            entity.setLineThree(e.getLine3());
            entity.setRedPacketMoney(config.getRedPackageMoney());
            entity.setFileSize(e.getFileSize());
            entity.setFileKey(e.getFileKey());
            entity.setIsTranscode(0);
            return entity;
        }).collect(Collectors.toList());
        fsUserCourseVideoMapper.insertBatchFsUserCourseVideo(collect);
    }

    @Override
    public void batchUpdateRed(List<BatchRedUpdate> list) {
        list.forEach(e -> {
            fsUserCourseVideoMapper.updateRedPacketMoney(e.getVideoId(), e.getRedPacketMoney());
        });
    }

    /**
     * 获取选项列表
     * @param params    参数
     * @return  list
     */
    @Override
    public List<OptionsVO> selectVideoListByMap(Map<String, Object> params) {
        return fsUserCourseVideoMapper.selectVideoListByMap(params);
    }

    @Override
    public List<FsCourseVideoListBySidebarVO> getFsCourseVideoListBySidebar(FsCourseListBySidebarParam param) {
        return fsUserCourseVideoMapper.getFsCourseVideoListBySidebar(param);
    }

    @Override
    public R createMiniLink(FsCourseLinkMiniParam param) {

        QwUser qwUser = qwExternalContactService.getQwUserByRedis(param.getCorpId().trim(), param.getQwUserId().trim());

        if (qwUser==null||qwUser.getCompanyId()==null||qwUser.getCompanyUserId()==null){
            return R.error("员工未绑定 销售公司 或 销售 请先绑定");
        }

        QwCompany qwCompany = iQwCompanyService.getQwCompanyByRedis(param.getCorpId());

        if (qwCompany == null ) {
            return  R.error().put("msg","企业不存在，请联系管理员");
        }

        //看课记录
        addWatchLogIfNeeded(param.getVideoId(), param.getCourseId(),param.getFsUserId(),qwUser , param.getExternalUserId());

        //生成小程序链接
        String linkByMiniApp = createLinkByMiniApp(new Date(), param.getCourseId(), param.getVideoId(), qwUser, param.getExternalUserId(),2,null,0);

        JSONObject news = new JSONObject(true);
        news.put("miniprogramAppid", qwCompany.getMiniAppId());
        news.put("miniprogramTitle", param.getTitle());
        news.put("miniprogramPicUrl", "https://cos.his.cdwjyyh.com/fs/20250523/9c8af5735d784847818cada7fa776a7b.jpg");
        news.put("miniprogramPage", linkByMiniApp);

        return R.ok().put("data",news);

    }

    @Override
    public R createCartLink(FsCourseLinkMiniParam param) {

        QwUser qwUser = qwExternalContactService.getQwUserByRedis(param.getCorpId().trim(), param.getQwUserId().trim());

        if (qwUser==null||qwUser.getCompanyId()==null||qwUser.getCompanyUserId()==null){
            return R.error("员工未绑定 销售公司 或 销售 请先绑定");
        }

        QwCompany qwCompany = iQwCompanyService.getQwCompanyByRedis(param.getCorpId());

        if (qwCompany == null ) {
            return  R.error().put("msg","企业不存在，请联系管理员");
        }

        String json = configService.selectConfigByKey("course.config");
        CourseConfig config = JSON.parseObject(json, CourseConfig.class);

        if (config == null) {
            return R.error().put("msg","课程默认配置为空，请联系管理员");
        }

        //域名
        String domainName = companyUserMapper.selectDomainByUserId(qwUser.getCompanyUserId());
        if (StringUtils.isEmpty(domainName)){
            domainName = config.getRealLinkDomainName();
        }

        addWatchLogIfNeeded(param.getVideoId(), param.getCourseId(),param.getFsUserId(),qwUser , param.getExternalUserId());

        String linkByCartLink = createLinkByMiniApp(new Date(), param.getCourseId(), param.getVideoId(), qwUser, param.getExternalUserId(),1,domainName,0);


        //生成卡片链接
        JSONObject news = new JSONObject(true); // true 表示保持字段顺序
        news.put("linkTitle", param.getTitle());
        news.put("linkDescribe", param.getTitle());
        news.put("linkImageUrl", "https://cos.his.cdwjyyh.com/fs/20250523/9c8af5735d784847818cada7fa776a7b.jpg");
        news.put("linkUrl", linkByCartLink);

        return R.ok().put("data",news);

    }


    //插入观看记录
    private void addWatchLogIfNeeded(Long videoId, Long courseId,
                                     Long fsUserId, QwUser qwUser,Long externalId) {

        try {

            FsCourseWatchLog watchLog = new FsCourseWatchLog();
            watchLog.setVideoId(videoId);
            watchLog.setQwExternalContactId(externalId);
            watchLog.setSendType(2);
            watchLog.setQwUserId(qwUser.getId());
            watchLog.setDuration(0L);
            watchLog.setCourseId(courseId);
            watchLog.setCompanyUserId(qwUser.getCompanyUserId());
            watchLog.setCompanyId(qwUser.getCompanyId());
            watchLog.setCreateTime(new Date());
            watchLog.setUpdateTime(new Date());
            watchLog.setLogType(3);

            if (fsUserId == null) {
                fsUserId=0L;
            }

            watchLog.setUserId(fsUserId);

            //存看课记录
            courseWatchLogMapper.insertOrUpdateFsCourseWatchLog(watchLog);
        }catch (Exception e){
            logger.error("一键群发失败-插入观看记录失败："+e.getMessage());
        }


    }

    private String createLinkByMiniApp(Date sendTime, Long courseId, Long videoId,
                                       QwUser qwUser, Long externalId,int type,String domainName,Integer isRoom) {

        FsCourseLink link = new FsCourseLink();
        link.setCompanyId(qwUser.getCompanyId());
        link.setQwUserId(qwUser.getId());
        link.setCompanyUserId(qwUser.getCompanyUserId());
        link.setVideoId(videoId);
        link.setCorpId(qwUser.getCorpId());
        link.setCourseId(courseId);
        link.setQwExternalId(externalId);
        link.setIsRoom(isRoom);
        if (type == 1) {
            link.setLinkType(0);
        }else {
            link.setLinkType(3);
        }

        String randomString = generateRandomStringWithLock();
        if (StringUtil.strIsNullOrEmpty(randomString)){
            link.setLink(UUID.randomUUID().toString().replace("-", ""));
        }else {
            link.setLink(randomString);
        }

        link.setCreateTime(sendTime);

        FsCourseRealLink courseMap = new FsCourseRealLink();
        BeanUtils.copyProperties(link,courseMap);

        String courseJson = JSON.toJSONString(courseMap);

        String realLinkFull = null;

        if (type == 1) {
            realLinkFull = REAL_LINK_PREFIX + courseJson;
        }else {
            realLinkFull = miniappRealLink + courseJson;
        }

        link.setRealLink(realLinkFull);


        // 使用 Java 8 时间 API 计算过期时间
        LocalDateTime sendDateTime = sendTime.toInstant().atZone(ZoneId.systemDefault()).toLocalDateTime();
        LocalDateTime expireDateTime = sendDateTime.plusDays(0);
        expireDateTime = expireDateTime.toLocalDate().atTime(23, 59, 59);
        Date updateTime = Date.from(expireDateTime.atZone(ZoneId.systemDefault()).toInstant());
        link.setUpdateTime(updateTime);

        //存短链-
        fsCourseLinkMapper.insertFsCourseLink(link);

        if (type==1){
            return domainName + SHORT_LINK_PREFIX + link.getLink();
        }else {
            return link.getRealLink();
        }

    }
    //会员-更新心跳时间
    public void updateHeartbeatWx(FsUserCourseVideoUParam param) {
        String redisKey = "h5wxuser:watch:heartbeat:" + param.getUserId() + ":" + param.getVideoId() + ":" + param.getCompanyUserId();
        redisCache.setCacheObject(redisKey, LocalDateTime.now().toString());
        // 设置 Redis 记录的过期时间（例如 5 分钟）
        redisCache.expire(redisKey, 300, TimeUnit.SECONDS);
    }


    @Override
    public R isAllowAnswer(FsUserCourseVideoFinishUParam param) {
        try {
            // 参数校验
            if (param.getVideoId() == null || param.getDuration() == null) {
                return R.error("参数不完整，缺少videoId或duration");
            }

            // 获取视频时长（优先从Redis缓存获取）
            Long videoDuration = getVideoDuration(param.getVideoId());

            // 校验总时长
            return checkTotalDuration(param.getDuration(), videoDuration);
        } catch (IllegalArgumentException e) {
            return R.error(e.getMessage());
        } catch (Exception e) {
            log.error("检查总时长异常, 参数: {}", param, e);
            return R.error("系统异常，请稍后重试");
        }
    }

    @Override
    public List<FsUserCourseVideoPageListVO> selectCourseVideoListByMap(Map<String, Object> params) {
        return fsUserCourseVideoMapper.selectFsUserCourseVideoListByMap(params);
    }
    /**
     * 生成唯一键
     */
    private String getKey(Long periodId, Long courseId, Long videoId, Long companyUserId) {
        return String.format("%d_%d_%d_%d", periodId, courseId, videoId, companyUserId);
    }

    @Override
    public ResponseResult<Boolean> setWatchCourseTime(List<FsWatchCourseTimeParam> paramList) {
        if (CollectionUtils.isEmpty(paramList)) {
            return ResponseResult.fail(400, "参数不能为空");
        }

        // 1. 查询参数
        List<CompanyUserTimeQueryParam> queryList = paramList.stream()
                .map(param -> {
                    CompanyUserTimeQueryParam query = new CompanyUserTimeQueryParam();
                    query.setPeriodId(param.getPeriodId());
                    query.setCourseId(param.getCourseId());
                    query.setVideoId(param.getVideoId());
                    query.setCompanyUserId(param.getCompanyUserId());
                    return query;
                })
                .collect(Collectors.toList());

        // 2. 批量查询现有的记录
        List<FsUserCourseCompanyUserTime> existingRecords = companyUserTimeMapper.batchSelectByParams(queryList);
        Map<String, FsUserCourseCompanyUserTime> existingMap = existingRecords.stream()
                .collect(Collectors.toMap(record -> getKey(record.getPeriodId(), record.getCourseId(), record.getVideoId(), record.getCompanyUserId()),
                        record -> record));

        // 3. 分离需要更新和插入的记录
        List<FsUserCourseCompanyUserTime> toUpdate = new ArrayList<>();
        List<FsUserCourseCompanyUserTime> toInsert = new ArrayList<>();
        Date now = DateUtils.getNowDate();

        for (FsWatchCourseTimeParam param : paramList) {
            String key = getKey(param.getPeriodId(), param.getCourseId(), param.getVideoId(), param.getCompanyUserId());
            FsUserCourseCompanyUserTime record = existingMap.get(key);

            if (record != null) {
                // 需要更新
                record.setStartDateTime(param.getStartDateTime());
                record.setEndDateTime(param.getEndDateTime());
                record.setUpdateTime(now);
                toUpdate.add(record);
            } else {
                // 需要插入
                FsUserCourseCompanyUserTime newRecord = new FsUserCourseCompanyUserTime();
                newRecord.setPeriodId(param.getPeriodId());
                newRecord.setCourseId(param.getCourseId());
                newRecord.setVideoId(param.getVideoId());
                newRecord.setCompanyUserId(param.getCompanyUserId());
                newRecord.setCompanyId(param.getCompanyId());
                newRecord.setStartDateTime(param.getStartDateTime());
                newRecord.setEndDateTime(param.getEndDateTime());
                newRecord.setCreateTime(now);
                toInsert.add(newRecord);
            }
        }

        // 4. 执行批量更新和插入
        if (!toUpdate.isEmpty()) {
            companyUserTimeMapper.batchUpdate(toUpdate);
        }
        if (!toInsert.isEmpty()) {
            companyUserTimeMapper.batchInsert(toInsert);
        }

        return ResponseResult.ok();
    }

    @Override
    public R createRoomMiniLink(FsCourseLinkMiniParam param) {
        QwUser qwUser = qwExternalContactService.getQwUserByRedis(param.getCorpId().trim(), param.getQwUserId().trim());

        if (qwUser==null||qwUser.getCompanyId()==null||qwUser.getCompanyUserId()==null){
            return R.error("员工未绑定 销售公司 或 销售 请先绑定");
        }

        QwCompany qwCompany = iQwCompanyService.getQwCompanyByRedis(param.getCorpId());

        if (qwCompany == null ) {
            return  R.error().put("msg","企业不存在，请联系管理员");
        }

        //生成小程序链接
        String linkByMiniApp = createLinkByMiniApp(new Date(), param.getCourseId(), param.getVideoId(), qwUser, param.getExternalUserId(),2,null,1);

        JSONObject news = new JSONObject(true);
        news.put("miniprogramAppid", qwCompany.getMiniAppId());
        news.put("miniprogramTitle", param.getTitle());
        news.put("miniprogramPicUrl", "https://cos.his.cdwjyyh.com/fs/20250523/9c8af5735d784847818cada7fa776a7b.jpg");
        news.put("miniprogramPage", linkByMiniApp);

        return R.ok().put("data",news);
    }

    /**
     * 获取视频时长（优先从Redis获取，不存在则查数据库）
     */
    private Long getVideoDuration(Long videoId) {
        String redisKey = "h5user:video:duration:" + videoId;
        Long duration = redisCache.getCacheObject(redisKey);

        if (duration == null) {
            FsUserCourseVideoQVO videoInfo = selectFsUserCourseVideoByVideoIdVO(videoId);
            if (videoInfo == null || videoInfo.getDuration() == null) {
                throw new IllegalArgumentException("视频时长信息不存在");
            }
            duration = videoInfo.getDuration();

            // 将查询结果缓存到Redis，设置适当过期时间
            redisCache.setCacheObject(redisKey, duration);
        }

        return duration;
    }

    /**
     * 时长校验服务实现
     *
     * @param duration1
     * @param duration2
     * @return
     */
    public R checkTotalDuration(Long duration1, Long duration2) {
        // 参数校验
        if (duration1 == null || duration2 == null) {
            throw new IllegalArgumentException("时长参数不能为null");
        }

        if (duration1 < 0 || duration2 < 0) {
            throw new IllegalArgumentException("时长不能为负数");
        }
        // 获取并验证配置
        CourseConfig config = getValidatedConfig();

        // 根据配置模式进行校验
        switch (config.getCompletionMode()) {
            case 1: // 百分比模式
                return checkPercentageMode(duration1, duration2, config);
            case 2: // 分钟数模式
                return checkMinutesMode(duration1, config);
            default:
                return R.error("无效的完成模式配置");
        }
    }

    /**
     * 获取并验证课程配置
     */
    private CourseConfig getValidatedConfig() {
        String json = configService.selectConfigByKey("course.config");
        if (StringUtils.isBlank(json)) {
            throw new IllegalStateException("课程配置不存在");
        }

        try {
            CourseConfig config = JSONUtil.toBean(json, CourseConfig.class);
            if (config == null || config.getCompletionMode() == null) {
                throw new IllegalStateException("课程配置不完整");
            }
            return config;
        } catch (Exception e) {
            throw new IllegalStateException("解析课程配置失败");
        }
    }

    /**
     * 百分比模式校验
     */
    private R checkPercentageMode(long duration1, long duration2, CourseConfig config) {
        if (config.getAnswerRate() == null) {
            return R.error("百分比模式未配置达标比例");
        }
        long percentage = (duration1 * 100 / duration2);

        boolean isPassed = percentage >= config.getAnswerRate();
        return isPassed ? R.ok() : R.error(String.format("观看进度%d%%未达标(需%d%%)",
                percentage,config.getAnswerRate()));
    }

    /**
     * 分钟数模式校验
     */
    private R checkMinutesMode(long videoDuration, CourseConfig config) {
        if (config.getMinutesNum() == null) {
            return R.error("分钟数模式未配置达标分钟数");
        }

        int i = config.getMinutesNum() * 60;
        boolean isPassed = videoDuration > i;

        return isPassed ? R.ok() : R.error(String.format("观看时长%d分钟未达标(需大于%d分钟)",
                videoDuration/60, config.getMinutesNum()));
    }

}
