package com.fs.his.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.his.mapper.FsUserOperationLogMapper;
import com.fs.his.domain.FsUserOperationLog;
import com.fs.his.service.IFsUserOperationLogService;

/**
 * 用户操作日志Service业务层处理
 * 
 * @author fs
 * @date 2025-07-04
 */
@Service
public class FsUserOperationLogServiceImpl extends ServiceImpl<FsUserOperationLogMapper, FsUserOperationLog> implements IFsUserOperationLogService {

    /**
     * 查询用户操作日志
     * 
     * @param logId 用户操作日志主键
     * @return 用户操作日志
     */
    @Override
    public FsUserOperationLog selectFsUserOperationLogByLogId(Long logId)
    {
        return baseMapper.selectFsUserOperationLogByLogId(logId);
    }

    /**
     * 查询用户操作日志列表
     * 
     * @param fsUserOperationLog 用户操作日志
     * @return 用户操作日志
     */
    @Override
    public List<FsUserOperationLog> selectFsUserOperationLogList(FsUserOperationLog fsUserOperationLog)
    {
        return baseMapper.selectFsUserOperationLogList(fsUserOperationLog);
    }

    /**
     * 新增用户操作日志
     * 
     * @param fsUserOperationLog 用户操作日志
     * @return 结果
     */
    @Override
    public int insertFsUserOperationLog(FsUserOperationLog fsUserOperationLog)
    {
        fsUserOperationLog.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertFsUserOperationLog(fsUserOperationLog);
    }

    /**
     * 修改用户操作日志
     * 
     * @param fsUserOperationLog 用户操作日志
     * @return 结果
     */
    @Override
    public int updateFsUserOperationLog(FsUserOperationLog fsUserOperationLog)
    {
        return baseMapper.updateFsUserOperationLog(fsUserOperationLog);
    }

    /**
     * 批量删除用户操作日志
     * 
     * @param logIds 需要删除的用户操作日志主键
     * @return 结果
     */
    @Override
    public int deleteFsUserOperationLogByLogIds(Long[] logIds)
    {
        return baseMapper.deleteFsUserOperationLogByLogIds(logIds);
    }

    /**
     * 删除用户操作日志信息
     * 
     * @param logId 用户操作日志主键
     * @return 结果
     */
    @Override
    public int deleteFsUserOperationLogByLogId(Long logId)
    {
        return baseMapper.deleteFsUserOperationLogByLogId(logId);
    }
}
