package com.fs.ipad;


import com.alibaba.fastjson.JSON;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.core.redis.RedisCacheT;
import com.fs.common.exception.base.BaseException;
import com.fs.common.utils.StringUtils;
import com.fs.ipad.vo.*;
import com.fs.wxwork.dto.*;
import com.fs.wxwork.service.WxWorkServiceNew;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Component;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.function.Supplier;

@Component
@AllArgsConstructor
public class IpadSendUtils {

    private final WxWorkServiceNew wxWorkService;
    private final RedisCacheT<String> redisCache;
    private final RedisCache redisCacheUrl;
    private final String FILE_KEY = "ipad:upload:";

    /**
     * 发送卡片消息
     */
    public WxWorkResponseDTO<WxwSendLinkMsgRespDTO> sendLink(LinkVo vo){
        WxwSendLinkMsgDTO dto = new WxwSendLinkMsgDTO();
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setUrl(vo.getUrl());
        dto.setTitle(vo.getTitle());
        dto.setContent(vo.getContent());
        dto.setImgurl(vo.getImgUrl());
        dto.setIsRoom(vo.isRoom());
        return wxWorkService.SendLinkMsg(dto, vo.getServerId());
    }

    /**
     * 发送文本
     */
    public WxWorkResponseDTO<WxWorkSendTextMsgRespDTO> sendTxt(TxtVo vo){
        WxWorkSendTextMsgDTO dto = new WxWorkSendTextMsgDTO();
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setContent(vo.getContent());
        dto.setIsRoom(vo.isRoom());
        return wxWorkService.SendTextMsg(dto, vo.getServerId());
    }

    // 公共文件获取
    private <T> T getFile(String key, Class<T> clazz, Supplier<T> supplier) {
        String obj = redisCache.getCacheObject(key);
        T t;
        if(StringUtils.isEmpty(obj)){
            t = supplier.get();
            redisCache.setCacheObject(key, JSON.toJSONString(t), 3, TimeUnit.DAYS);
        }else{
            t = JSON.parseObject(obj, clazz);
        }
        return t;
    }

    /**
     * 发送图片
     */
    public WxWorkResponseDTO<WxwSendCDNImgMsgRespDTO> sendImg(FileVo vo){
        WxCdnUploadImgLinkResp resp = getFile(FILE_KEY + "img:" + vo.getUrl(), WxCdnUploadImgLinkResp.class, () -> uploadImage(vo.getUuid(), vo.getServerId(), vo.getUrl()));
        WxwSendCDNImgMsgDTO dto = new WxwSendCDNImgMsgDTO();
        dto.setCdnkey(resp.getCdn_key());
        dto.setAeskey(resp.getAes_key());
        dto.setMd5(resp.getMd5());
        dto.setFileSize(resp.getSize());
        dto.setFileSize(resp.getSize());
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setIsRoom(vo.isRoom());

        dto.setWidth(resp.getWidth());
        dto.setHeight(resp.getHeight());
        dto.setMid_image_size(resp.getMid_image_size());
        dto.setThumb_file_size(resp.getThumb_file_size());
        dto.setThumb_image_width(resp.getThumb_image_width());
        dto.setThumb_image_height(resp.getThumb_image_height());
        dto.setThumb_file_md5(resp.getThumb_file_md5());
        return wxWorkService.SendCDNImgMsg(dto, vo.getServerId());
    }
    /**
     * 发送文件
     */
    public WxWorkResponseDTO<WxwSendCDNFileMsgRespDTO> sendFile(FileVo vo){
        WxwUploadCdnLinkFileRespDTO resp = getFile(FILE_KEY + "file:" + vo.getUrl(), WxwUploadCdnLinkFileRespDTO.class, () -> uploadFile(vo.getUuid(), vo.getServerId(), vo.getUrl()));
        WxwSendCDNFileMsgDTO dto = new WxwSendCDNFileMsgDTO();
        dto.setCdnkey(resp.getCdn_key());
        dto.setAeskey(resp.getAes_key());
        dto.setMd5(resp.getMd5());
        dto.setFileSize(resp.getSize().longValue());
        dto.setFile_name(vo.getUrl().substring(vo.getUrl().lastIndexOf('/') + 1));
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setIsRoom(vo.isRoom());
        return wxWorkService.SendCDNFileMsg(dto, vo.getServerId());
    }
    /**
     * 发送文件
     */
    public WxWorkResponseDTO<WxwSendCDNVoiceMsgRespDTO> sendVoice(FileVo vo){
        WxwUploadCdnLinkFileRespDTO resp = getFile(FILE_KEY + "voice:" + vo.getUrl(), WxwUploadCdnLinkFileRespDTO.class, () -> uploadFile(vo.getUuid(), vo.getServerId(), vo.getUrl()));
        WxwSendCDNVoiceMsgDTO dto = new WxwSendCDNVoiceMsgDTO();
        dto.setCdnkey(resp.getCdn_key());
        dto.setVoice_time(vo.getVoiceTime());
        dto.setAeskey(resp.getAes_key());
        dto.setMd5(resp.getMd5());
        dto.setFileSize(resp.getSize());
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setIsRoom(vo.isRoom());
        return wxWorkService.SendCDNVoiceMsg(dto, vo.getServerId());
    }
    /**
     * 发送文件
     */
    public WxWorkResponseDTO<WxwSendCDNVideoMsgRespDTO> sendVideo(FileVo vo){
        WxCdnUploadVideoResp resp = getFile(FILE_KEY + "voice:" + vo.getUrl(), WxCdnUploadVideoResp.class, () -> uploadVideo(vo.getUuid(), vo.getServerId(), vo.getUrl()));
        WxwSendCDNVideoMsgDTO dto = new WxwSendCDNVideoMsgDTO();
        dto.setCdnkey(resp.getCdn_key());
        dto.setAeskey(resp.getAes_key());
        dto.setMd5(resp.getMd5());
        dto.setFileSize(resp.getSize());
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setIsRoom(vo.isRoom());
        return wxWorkService.SendCDNVideoMsg(dto, vo.getServerId());
    }
    /**
     * 发送小程序
     */
    public WxWorkResponseDTO<WxWorkSendAppMsgRespDTO> sendMiniProgram(MiniProgramVo vo){
        WxCdnUploadImgLinkResp resp = getFile(FILE_KEY + "voice:" + vo.getImgUrl(), WxCdnUploadImgLinkResp.class, () -> uploadImage(vo.getUuid(), vo.getServerId(), vo.getImgUrl()));
        WxWorkSendAppMsgDTO dto = new WxWorkSendAppMsgDTO();
        dto.setCdnkey(resp.getCdn_key());
        dto.setAeskey(resp.getAes_key());
        dto.setMd5(resp.getMd5());
        dto.setFileSize(resp.getSize());
        dto.setUuid(vo.getUuid());
        dto.setSend_userid(userIds(vo));
        dto.setIsRoom(vo.isRoom());
        dto.setDesc(vo.getDesc());
        dto.setTitle(vo.getTitle());
        dto.setWeappIconUrl(vo.getWeappIconUrl());
        dto.setUsername(vo.getUsername());
        dto.setPagepath(vo.getPagepath());
        dto.setAppid(vo.getAppid());
        return wxWorkService.SendAppMsg(dto, vo.getServerId());
    }





    /**
     * 获取发送对象的userid
     * @param vo 调用接口参数
     * @return 返回的userid
     */
    private Long userIds(BaseVo vo){
        if(vo.isRoom()){
            return chatIds(vo);
        }
        WxWorkUserId2VidDTO wxWorkUserId2VidDTO = new WxWorkUserId2VidDTO();
        wxWorkUserId2VidDTO.setOpenid(Collections.singletonList(vo.getExId()));
        wxWorkUserId2VidDTO.setUuid(vo.getUuid());
        WxWorkResponseDTO<List<WxWorkVid2UserIdRespDTO>> WxWorkVid2UserIdRespDTO = wxWorkService.UserId2Vid(wxWorkUserId2VidDTO, vo.getServerId());
//        if(WxWorkVid2UserIdRespDTO.getErrcode() != 0){
//            String errmsg = WxWorkVid2UserIdRespDTO.getErrmsg();
//            if("实例不存在或在，规定时间内未完成扫码登录uuid失效。".equals(WxWorkVid2UserIdRespDTO.getErrmsg())){
//                errmsg += "serverId：" + vo.getServerId() + "====url：" + redisCache.getCacheObject("serverId:" + vo.getServerId());
//            }
//            throw new BaseException(errmsg);
//        }
        List<WxWorkVid2UserIdRespDTO> data = WxWorkVid2UserIdRespDTO.getData();
        if(data.isEmpty()) throw new BaseException("未找到用户");
        return data.get(0).getUser_id();
    }

    /**
     * 获取发送群的ID
     * @param vo 调用接口参数
     * @return 返回的userid
     */
    private Long chatIds(BaseVo vo){
        WxWorkChatIdToRoomIdDTO tdo = new WxWorkChatIdToRoomIdDTO();
        tdo.setChatid(vo.getExId());
        tdo.setUuid(vo.getUuid());
        WxWorkResponseDTO<WxWorkChatIdToRoomIdResp> result = wxWorkService.ChatIdToRoomId(tdo, vo.getServerId());
        if(result.getErrcode() != 0){
            throw new BaseException(result.getErrmsg());
        }
        WxWorkChatIdToRoomIdResp data = result.getData();
        if(data == null || data.getRoom_id() == null) throw new BaseException("未找到用户");
        return data.getRoom_id();
    }

    /**
     * 上传图片
     * @param uuid     登录唯一标识
     * @param serverId 请求服务器ID
     * @param url      上传图片地址
     * @return 上传的返回信息
     */
    private WxCdnUploadImgLinkResp uploadImage(String uuid, Long serverId, String url){
        WxCdnUploadImgLinkDTO dto = new WxCdnUploadImgLinkDTO();
        dto.setUuid(uuid);
        dto.setUrl(enUrl(url));
        WxWorkResponseDTO<WxCdnUploadImgLinkResp> result = wxWorkService.cdnUploadImgLink(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("上传图片失败：" + result.getErrmsg());
        return result.getData();
    }
    /**
     * 上传视频
     * @param uuid     登录唯一标识
     * @param serverId 请求服务器ID
     * @param url      上传图片地址
     * @return 上传的返回信息
     */
    private WxCdnUploadVideoResp uploadVideo(String uuid, Long serverId, String url){
        WxCdnUploadVideoLinkDTO dto = new WxCdnUploadVideoLinkDTO();
        dto.setUuid(uuid);
        dto.setUrl(enUrl(url));
        dto.setFilename(url.substring(url.lastIndexOf('/') + 1));
        WxWorkResponseDTO<WxCdnUploadVideoResp> result = wxWorkService.uploadCdnVideoLink(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("上传视频失败：" + result.getErrmsg());
        return result.getData();
    }
    /**
     * 上传语言
     * @param uuid     登录唯一标识
     * @param serverId 请求服务器ID
     * @param url      上传图片地址
     * @return 上传的返回信息
     */
    private WxwUploadCdnLinkFileRespDTO uploadSilk(String uuid, Long serverId, String url){
        WxwUploadCdnLinkFileDTO dto = new WxwUploadCdnLinkFileDTO();
        dto.setUuid(uuid);
        dto.setUrl(enUrl(url));
        WxWorkResponseDTO<WxwUploadCdnLinkFileRespDTO> result = wxWorkService.uploadCdnLinkFile(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("上传语言失败：" + result.getErrmsg());
        return result.getData();
    }
    /**
     * 上传文件
     * @param uuid     登录唯一标识
     * @param serverId 请求服务器ID
     * @param url      上传图片地址
     * @return 上传的返回信息
     */
    private WxwUploadCdnLinkFileRespDTO uploadFile(String uuid, Long serverId, String url){
        WxwUploadCdnLinkFileDTO dto = new WxwUploadCdnLinkFileDTO();
        dto.setUuid(uuid);
        dto.setUrl(enUrl(url));
        dto.setFilename(url.substring(url.lastIndexOf('/') + 1));
        WxWorkResponseDTO<WxwUploadCdnLinkFileRespDTO> result = wxWorkService.uploadCdnLinkFile(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("上传文件失败：" + result.getErrmsg());
        return result.getData();
    }

    /**
     * 上传大文件
     * @param uuid     登录唯一标识
     * @param serverId 请求服务器ID
     * @param url      上传图片地址
     * @return 上传的返回信息
     */
    private WxBigFileUploadLinkResp uploadBigFile(String uuid, Long serverId, String url){
        WxBigFileUploadLinkDTO dto = new WxBigFileUploadLinkDTO();
        dto.setUuid(uuid);
        dto.setFileurl(enUrl(url));
        dto.setFilename(url.substring(url.lastIndexOf('/') + 1));
        WxWorkResponseDTO<WxBigFileUploadLinkResp> result = wxWorkService.bigFileUploadLink(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("上传大文件失败：" + result.getErrmsg());
        return result.getData();
    }

    public WxLoginResp isLogin(String uuid, Long serverId){
        WxLoginDTO dto = new WxLoginDTO();
        dto.setUuid(uuid);
        WxWorkResponseDTO<WxLoginResp> result = wxWorkService.isLogin(dto, serverId);
        if(result.getErrcode() != 0) throw new BaseException("验证登录失败：" + result.getErrmsg());
        return result.getData();
    }

    private static String enUrl(String url) {
        try {
            // 先通过URL类自动编码
            URL urlObj = new URL(url);
            // 提取组件并构建URI（自动编码非ASCII字符）
            URI uri = new URI(
                    urlObj.getProtocol(),
                    urlObj.getUserInfo(),
                    urlObj.getHost(),
                    urlObj.getPort(),
                    urlObj.getPath(),
                    urlObj.getQuery(),
                    urlObj.getRef()
            );
            return uri.toASCIIString();
        } catch (MalformedURLException e) {
            throw new BaseException("URL格式异常: " + url + "======" + e.getMessage());
        } catch (URISyntaxException e) {
            throw new BaseException("URI语法异常: " + url + "======" + e.getMessage());
        }
    }

    public void loginOut(String uuid, Long serverId){
        WxWorkGetQrCodeDTO dto = new WxWorkGetQrCodeDTO();
        dto.setUuid(uuid);
        wxWorkService.LoginOut(dto, serverId);
    }
}
