package com.fs.live.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fs.common.annotation.Excel;
import com.fs.his.param.BaseParam;
import lombok.Data;
import com.fs.common.core.domain.BaseEntity;
import lombok.EqualsAndHashCode;

/**
 * 订单对象 live_order
 *
 * @author fs
 * @date 2025-07-08
 */
@Data
@TableName("live_order")
public class LiveOrder extends BaseParam {

    /** 订单ID */
    @TableId(type= IdType.AUTO)
    private Long orderId;

    /** 直播ID */
    @Excel(name = "直播ID")
    private Long liveId;

    /** $column.columnComment */
    @Excel(name = "店铺ID")
    private Long storeId;

    /** 订单号 */
    @Excel(name = "订单号")
    private String orderCode;

    /** 用户id */
    @Excel(name = "用户id")
    private String userId;

    /** 收货人 */
    @Excel(name = "收货人")
    private String userName;

    /** 收货人电话 */
    @Excel(name = "收货人电话")
    private String userPhone;

    /** 详细地址 */
    @Excel(name = "详细地址")
    private String userAddress;

    /** 购物车id */
    @Excel(name = "购物车id")
    private String cartId;

    /** 订单商品总数 */
    @Excel(name = "订单商品总数")
    private String totalNum;

    /** 订单总价 */
    @Excel(name = "订单总价")
    private BigDecimal totalPrice;

    /** 实际支付金额 */
    @Excel(name = "实际支付金额")
    private BigDecimal payPrice;

    /** 支付金额 */
    @Excel(name = "支付金额")
    private BigDecimal payMoney;

    /** 支付状态 待支付 1已支付 */
    @Excel(name = "支付状态 待支付 1已支付")
    private String isPay;

    /** 取消理由*/
    @Excel(name = "取消理由")
    private String cancelReason;

    /** 支付时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "支付时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date payTime;

    /** 支付方式 1微信 */
    @Excel(name = "支付方式 1微信")
    private String payType;

    /** 订单状态（-1 : 申请退款 -2 : 退货成功 0：已取消 1：待支付 2：待发货；3：待收货；4：待评价；5：已完成） */
    @Excel(name = "订单状态", readConverterExp = "-=1,:=,申=请退款,-=2,:=,退=货成功,1=：待支付,2=：待发货；3：待收货；4：待评价；5：已完成")
    private Integer status;

    /** 0 未退款 1 申请中 2 已退款 */
    @Excel(name = "0 未退款 1 申请中 2 已退款")
    private String refundStatus;

    /** 退款图片 */
    @Excel(name = "退款图片")
    private String refundImg;

    /** 退款用户说明 */
    @Excel(name = "退款用户说明")
    private String refundExplain;

    /** 退款时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "退款时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date refundTime;

    /** 不退款的理由 */
    @Excel(name = "不退款的理由")
    private String refundReason;

    /** 退款金额 */
    @Excel(name = "退款金额")
    private BigDecimal refundMoney;

    /** 快递公司编号 */
    @Excel(name = "快递公司编号")
    private String deliveryCode;

    /** 快递名称 */
    @Excel(name = "快递名称")
    private String deliveryName;

    /** 快递单号 */
    @Excel(name = "快递单号")
    private String deliverySn;

    /** 是否删除 */
    @Excel(name = "是否删除")
    private String isDel;

    /** 成本价 */
    @Excel(name = "成本价")
    private BigDecimal costPrice;

    /** 核销码 */
    @Excel(name = "核销码")
    private String verifyCode;

    /** 配送方式 1=快递 ，2=门店自提 */
    @Excel(name = "配送方式 1=快递 ，2=门店自提")
    private Integer shippingType;

    /** 支付渠道(1微信小程序) */
    @Excel(name = "支付渠道(1微信小程序)")
    private String isChannel;

    /** $column.columnComment */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "支付渠道(1微信小程序)", width = 30, dateFormat = "yyyy-MM-dd")
    private Date finishTime;

    /** 发货时间 */
    @Excel(name = "发货时间")
    private String deliveryTime;

    /** 推广佣金 */
    @Excel(name = "推广佣金")
    private BigDecimal tuiMoney;

    /** 推广佣金状态 1已发放 0待发放 */
    @Excel(name = "推广佣金状态 1已发放 0待发放")
    private Integer tuiMoneyStatus;

    /** 上级推荐人ID */
    @Excel(name = "上级推荐人ID")
    private Long tuiUserId;

    /** orderItem字符串 */
    @Excel(name = "orderItem字符串")
    private String itemJson;

    /** 优惠金额 */
    @Excel(name = "优惠金额")
    private BigDecimal discountMoney;

    /** $column.columnComment */
    @Excel(name = "优惠金额")
    private Long userCouponId;

    /** 公司id */
    @Excel(name = "公司id")
    private Long companyId;

    /** 公司员工id */
    @Excel(name = "公司员工id")
    private Long companyUserId;

    /** 仓库代码 */
    @Excel(name = "仓库代码")
    private String storeHouseCode;

    /** 扩展订单ID */
    @Excel(name = "扩展订单ID")
    private String extendOrderId;

    /** 支付运费 */
    @Excel(name = "支付运费")
    private BigDecimal payDelivery;

    /** 剩余金额 */
    @Excel(name = "剩余金额")
    private BigDecimal payRemain;

    /** 物流状态 */
    @Excel(name = "物流状态")
    private Integer deliveryStatus;

    /** 物流结算状态 */
    @Excel(name = "物流结算状态")
    private Integer deliveryPayStatus;

    /** $column.columnComment */
    @Excel(name = "物流结算状态")
    private String deliveryPayTime;

    /** 物流跟踪状态 */
    @Excel(name = "物流跟踪状态")
    private String deliveryType;

    /** 物流结算金额 */
    @Excel(name = "物流结算金额")
    private BigDecimal deliveryPayMoney;

    /** 回单导入时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "回单导入时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date deliveryImportTime;

    /** 发货时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "发货时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date deliverySendTime;

    /** 是否可售后 */
    @Excel(name = "是否可售后")
    private Integer isAfterSales;

    /** 部门id */
    @Excel(name = "部门id")
    private Long deptId;

    /** 渠道 */
    @Excel(name = "渠道")
    private String channel;

    /** 订单来源 */
    @Excel(name = "订单来源")
    private Long source;

    /** 开票金额 */
    @Excel(name = "开票金额")
    private BigDecimal billPrice;

    /** 邮费 */
    @Excel(name = "邮费")
    private BigDecimal totalPostage;

    /** 支付邮费 */
    @Excel(name = "支付邮费")
    private BigDecimal payPostage;

    /** 消费赚取积分 */
    @Excel(name = "消费赚取积分")
    private BigDecimal gainIntegral;

    /** 使用积分 */
    @Excel(name = "使用积分")
    private BigDecimal useIntegral;

    /** 实际支付积分 */
    @Excel(name = "实际支付积分")
    private BigDecimal payIntegral;

    /** 给用户退了多少积分 */
    @Excel(name = "给用户退了多少积分")
    private BigDecimal backIntegral;

    /** 是否改价 */
    @Excel(name = "是否改价")
    private Integer isEditMoney;

    /** 创建时间*/
    @Excel(name = "创建时间")
    private Date createTime;

    /** 更新时间*/
    @Excel(name = "更新时间")
    private Date updateTime;

    /** 备注*/
    @Excel(name = "备注")
    private String remark;
}
