package com.fs.live.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.live.domain.LiveAnchor;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 主播Mapper接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface LiveAnchorMapper extends BaseMapper<LiveAnchor> {
    /**
     * 查询主播
     *
     * @param anchorId 主播主键
     * @return 主播
     */
    public LiveAnchor selectLiveAnchorByAnchorId(Long anchorId);

    /**
     * 查询企业主播
     * @param anchorId          主播ID
     * @param companyId         企业ID
     * @param companyUserId     企业用户ID
     * @return liveAnchor
     */
    LiveAnchor selectLiveAnchorByAnchorIdAndCompanyIdAndCompanyUserId(@Param("anchorId") Long anchorId, @Param("companyId") Long companyId, @Param("companyUserId") Long companyUserId);

    /**
     * 查询主播列表
     *
     * @param liveAnchor 主播
     * @return 主播集合
     */
    public List<LiveAnchor> selectLiveAnchorList(LiveAnchor liveAnchor);

    /**
     * 新增主播
     *
     * @param liveAnchor 主播
     * @return 结果
     */
    public int insertLiveAnchor(LiveAnchor liveAnchor);

    /**
     * 修改主播
     *
     * @param liveAnchor 主播
     * @return 结果
     */
    public int updateLiveAnchor(LiveAnchor liveAnchor);

    /**
     * 删除主播
     *
     * @param anchorId 主播主键
     * @return 结果
     */
    public int deleteLiveAnchorByAnchorId(Long anchorId);

    /**
     * 批量删除主播
     *
     * @param anchorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLiveAnchorByAnchorIds(Long[] anchorIds);
}
