package com.fs.live.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.his.domain.FsStoreProduct;
import com.fs.live.domain.LiveGoods;
import com.fs.live.vo.LiveGoodsVo;
import org.apache.ibatis.annotations.Param;

/**
 * 直播商品Mapper接口
 *
 * @author fs
 * @date 2025-07-08
 */
public interface LiveGoodsMapper extends BaseMapper<LiveGoods>{
    /**
     * 查询直播商品
     *
     * @param goodsId 直播商品主键
     * @return 直播商品
     */
    LiveGoods selectLiveGoodsByGoodsId(Long goodsId);

    /**
     * 查询直播商品列表
     *
     * @param liveGoods 直播商品
     * @return 直播商品集合
     */
    List<LiveGoods> selectLiveGoodsList(LiveGoods liveGoods);

    /**
     * 新增直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    int insertLiveGoods(LiveGoods liveGoods);

    /**
     * 修改直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    int updateLiveGoods(LiveGoods liveGoods);

    /**
     * 删除直播商品
     *
     * @param goodsId 直播商品主键
     * @return 结果
     */
    int deleteLiveGoodsByGoodsId(Long goodsId);

    /**
     * 批量删除直播商品
     *
     * @param goodsIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteLiveGoodsByGoodsIds(Long[] goodsIds);

    Long selectStoreIdByLiveId(Long liveId);

    /**
     * 新增直播商品
     *
     * @param liveGoodsList 直播商品
     * @return 结果
     */
    int insertLiveGoodsList(@Param("liveGoodsList") List<LiveGoods> liveGoodsList);

    /**
     * 批量查询商品ID
     *
     * @param liveId 直播ID
     * @return 商品ID集合
     */
    List<String> selectProductIdsByLiveId(@Param("liveId") Long liveId);

    /**
     * 批量查询商品信息
     *
     * @param liveGoods 直播商品
     * @return 商品信息集合
     */
    List<LiveGoodsVo> selectProductListByLiveId(LiveGoods liveGoods);
}
