package com.fs.live.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.live.domain.Live;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 直播Mapper接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface LiveMapper extends BaseMapper<Live>
{
    /**
     * 查询直播
     *
     * @param liveId 直播主键
     * @return 直播
     */
    public Live selectLiveByLiveId(Long liveId);

    /**
     * 查询企业直播
     * @param liveId        直播间ID
     * @param companyId     企业ID
     * @param companyUserId 企业用户ID
     * @return Live
     */
    Live selectLiveByLiveIdAndCompanyIdAndCompanyUserId(@Param("liveId") Long liveId, @Param("companyId") Long companyId, @Param("companyUserId") Long companyUserId);


    List<Live> selectLiveToStudent( @Param("liveName") String liveName,@Param("status") String status,@Param("startTime") String startTime,@Param("finishTime") String finishTime);

    /**
     * 查询直播列表
     *
     * @param live 直播
     * @return 直播集合
     */
    public List<Live> selectLiveList(Live live);

    /**
     * 新增直播
     *
     * @param live 直播
     * @return 结果
     */
    public int insertLive(Live live);

    /**
     * 修改直播
     *
     * @param live 直播
     * @return 结果
     */
    public int updateLive(Live live);

    /**
     * 删除直播
     *
     * @param liveId 直播主键
     * @return 结果
     */
    public int deleteLiveByLiveId(Long liveId);

    /**
     * 批量删除直播
     *
     * @param liveIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLiveByLiveIds(Long[] liveIds);

    @Select("select * from live where status = 2 and is_show=1 and is_del != 1")
    List<Live> liveList();
}
