package com.fs.live.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.live.domain.LiveAnchor;

import java.util.List;

/**
 * 主播Service接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface ILiveAnchorService extends IService<LiveAnchor>
{
    /**
     * 查询主播
     *
     * @param anchorId 主播主键
     * @return 主播
     */
    public LiveAnchor selectLiveAnchorByAnchorId(Long anchorId);

    /**
     * 查询企业主播
     *
     * @param anchorId 主播主键
     * @param companyId 企业ID
     * @param companyUserId 企业用户ID
     * @return 主播
     */
    LiveAnchor selectLiveAnchorByAnchorIdAndCompanyIdAndCompanyUserId(Long anchorId, Long companyId, Long companyUserId);

    /**
     * 查询主播列表
     *
     * @param liveAnchor 主播
     * @return 主播集合
     */
    public List<LiveAnchor> selectLiveAnchorList(LiveAnchor liveAnchor);

    /**
     * 新增主播
     *
     * @param liveAnchor 主播
     * @return 结果
     */
    public int insertLiveAnchor(LiveAnchor liveAnchor);

    /**
     * 修改主播
     *
     * @param liveAnchor 主播
     * @return 结果
     */
    public int updateLiveAnchor(LiveAnchor liveAnchor);

    /**
     * 批量删除主播
     *
     * @param anchorIds 需要删除的主播主键集合
     * @return 结果
     */
    public int deleteLiveAnchorByAnchorIds(Long[] anchorIds);

    /**
     * 删除主播信息
     *
     * @param anchorId 主播主键
     * @return 结果
     */
    public int deleteLiveAnchorByAnchorId(Long anchorId);
}
