package com.fs.live.service;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.common.core.domain.entity.SysUser;
import com.fs.company.domain.CompanyUser;
import com.fs.his.domain.FsStore;
import com.fs.his.domain.FsStoreProduct;
import com.fs.live.domain.LiveGoods;
import com.fs.live.vo.LiveGoodsVo;

/**
 * 直播商品Service接口
 *
 * @author fs
 * @date 2025-07-08
 */
public interface ILiveGoodsService extends IService<LiveGoods>{
    /**
     * 查询直播商品
     *
     * @param goodsId 直播商品主键
     * @return 直播商品
     */
    LiveGoods selectLiveGoodsByGoodsId(Long goodsId);

    /**
     * 查询直播商品列表
     *
     * @param liveGoods 直播商品
     * @return 直播商品集合
     */
    List<LiveGoods> selectLiveGoodsList(LiveGoods liveGoods);

    /**
     * 新增直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    int insertLiveGoods(LiveGoods liveGoods);

    /**
     * 修改直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    int updateLiveGoods(LiveGoods liveGoods);

    /**
     * 批量删除直播商品
     *
     * @param goodsIds 需要删除的直播商品主键集合
     * @return 结果
     */
    int deleteLiveGoodsByGoodsIds(Long[] goodsIds);

    /**
     * 删除直播商品信息
     *
     * @param goodsId 直播商品主键
     * @return 结果
     */
    int deleteLiveGoodsByGoodsId(Long goodsId);

    /**
     * 批量新增直播商品
     *
     * @param payload 包含 直播间和商品信息ids
     * @return 结果
     */
    int insertLiveGoods(Map<String, Object> payload, CompanyUser user);

    //FsStore getStoreByLiveId(Long liveId);

    /**
     * 查询直播商品列表
     *
     * @param liveGoods 直播商品
     * @return 直播商品集合
     */
    List<LiveGoodsVo> selectProductListByLiveId(LiveGoods liveGoods);
    Map<String, Object> getStoreByLiveId(Long liveId);

    int insertLiveGoodsAdmin(Map<String, Object> payload, SysUser user);
}
