package com.fs.live.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.live.domain.Live;

import java.util.List;
import java.util.Map;

/**
 * 直播Service接口
 *
 * @author fs
 * @date 2025-01-17
 */
public interface ILiveService extends IService<Live>
{
    /**
     * 查询直播
     *
     * @param liveId 直播主键
     * @return 直播
     */
    public Live selectLiveByLiveId(Long liveId);

    /**
     * 查询企业直播
     * @param liveId            直播ID
     * @param companyId         企业ID
     * @param companyUserId     企业用户ID
     * @return Live
     */
    Live selectLiveByLiveIdAndCompanyIdAndCompanyUserId(Long liveId, Long companyId, Long companyUserId);

    /**
     * 查询直播列表
     *
     * @param live 直播
     * @return 直播集合
     */
    public List<Live> selectLiveList(Live live);

    /**
     * 直播间学员查询直播列表
     *
     * @param
     * @return 直播集合
     */
    List<Live> selectLiveToStudent(String liveName,String status,String startTime,String finishTime);

    /**
     * 新增直播
     *
     * @param live 直播
     * @return 结果
     */
    public int insertLive(Live live);

    /**
     * 修改直播
     *
     * @param live 直播
     * @return 结果
     */
    public int updateLive(Live live);

    /**
     * 批量删除直播
     *
     * @param liveIds 需要删除的直播主键集合
     * @return 结果
     */
    public int deleteLiveByLiveIds(Long[] liveIds);

    /**
     * 删除直播信息
     *
     * @param liveId 直播主键
     * @return 结果
     */
    public int deleteLiveByLiveId(Long liveId);

    /**
     * 直播列表
     * @return
     */
    List<Live> liveList();

    Map<String, Object> createLiveRoom(Long liveId);

    Map<String, Object> getLiveRoom(String streamKey);
}
