package com.fs.live.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveAfterSalesMapper;
import com.fs.live.domain.LiveAfterSales;
import com.fs.live.service.ILiveAfterSalesService;

/**
 * 售后记录Service业务层处理
 * 
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveAfterSalesServiceImpl extends ServiceImpl<LiveAfterSalesMapper, LiveAfterSales> implements ILiveAfterSalesService {

    /**
     * 查询售后记录
     * 
     * @param id 售后记录主键
     * @return 售后记录
     */
    @Override
    public LiveAfterSales selectLiveAfterSalesById(Long id)
    {
        return baseMapper.selectLiveAfterSalesById(id);
    }

    /**
     * 查询售后记录列表
     * 
     * @param liveAfterSales 售后记录
     * @return 售后记录
     */
    @Override
    public List<LiveAfterSales> selectLiveAfterSalesList(LiveAfterSales liveAfterSales)
    {
        return baseMapper.selectLiveAfterSalesList(liveAfterSales);
    }

    /**
     * 新增售后记录
     * 
     * @param liveAfterSales 售后记录
     * @return 结果
     */
    @Override
    public int insertLiveAfterSales(LiveAfterSales liveAfterSales)
    {
        liveAfterSales.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertLiveAfterSales(liveAfterSales);
    }

    /**
     * 修改售后记录
     * 
     * @param liveAfterSales 售后记录
     * @return 结果
     */
    @Override
    public int updateLiveAfterSales(LiveAfterSales liveAfterSales)
    {
        return baseMapper.updateLiveAfterSales(liveAfterSales);
    }

    /**
     * 批量删除售后记录
     * 
     * @param ids 需要删除的售后记录主键
     * @return 结果
     */
    @Override
    public int deleteLiveAfterSalesByIds(Long[] ids)
    {
        return baseMapper.deleteLiveAfterSalesByIds(ids);
    }

    /**
     * 删除售后记录信息
     * 
     * @param id 售后记录主键
     * @return 结果
     */
    @Override
    public int deleteLiveAfterSalesById(Long id)
    {
        return baseMapper.deleteLiveAfterSalesById(id);
    }
}
