package com.fs.live.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveCartMapper;
import com.fs.live.domain.LiveCart;
import com.fs.live.service.ILiveCartService;

/**
 * 购物车Service业务层处理
 * 
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveCartServiceImpl extends ServiceImpl<LiveCartMapper, LiveCart> implements ILiveCartService {

    /**
     * 查询购物车
     * 
     * @param cardId 购物车主键
     * @return 购物车
     */
    @Override
    public LiveCart selectLiveCartByCardId(Long cardId)
    {
        return baseMapper.selectLiveCartByCardId(cardId);
    }

    /**
     * 查询购物车列表
     * 
     * @param liveCart 购物车
     * @return 购物车
     */
    @Override
    public List<LiveCart> selectLiveCartList(LiveCart liveCart)
    {
        return baseMapper.selectLiveCartList(liveCart);
    }

    /**
     * 新增购物车
     * 
     * @param liveCart 购物车
     * @return 结果
     */
    @Override
    public int insertLiveCart(LiveCart liveCart)
    {
        liveCart.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertLiveCart(liveCart);
    }

    /**
     * 修改购物车
     * 
     * @param liveCart 购物车
     * @return 结果
     */
    @Override
    public int updateLiveCart(LiveCart liveCart)
    {
        liveCart.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateLiveCart(liveCart);
    }

    /**
     * 批量删除购物车
     * 
     * @param cardIds 需要删除的购物车主键
     * @return 结果
     */
    @Override
    public int deleteLiveCartByCardIds(Long[] cardIds)
    {
        return baseMapper.deleteLiveCartByCardIds(cardIds);
    }

    /**
     * 删除购物车信息
     * 
     * @param cardId 购物车主键
     * @return 结果
     */
    @Override
    public int deleteLiveCartByCardId(Long cardId)
    {
        return baseMapper.deleteLiveCartByCardId(cardId);
    }
}
