package com.fs.live.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveEventConfMapper;
import com.fs.live.domain.LiveEventConf;
import com.fs.live.service.ILiveEventConfService;

/**
 * 直播触发事件配置Service业务层处理
 * 
 * @author fs
 * @date 2025-07-17
 */
@Service
public class LiveEventConfServiceImpl extends ServiceImpl<LiveEventConfMapper, LiveEventConf> implements ILiveEventConfService {

    /**
     * 查询直播触发事件配置
     * 
     * @param eventId 直播触发事件配置主键
     * @return 直播触发事件配置
     */
    @Override
    public LiveEventConf selectLiveEventConfByEventId(Long eventId)
    {
        return baseMapper.selectLiveEventConfByEventId(eventId);
    }

    /**
     * 查询直播触发事件配置列表
     * 
     * @param liveEventConf 直播触发事件配置
     * @return 直播触发事件配置
     */
    @Override
    public List<LiveEventConf> selectLiveEventConfList(LiveEventConf liveEventConf)
    {
        return baseMapper.selectLiveEventConfList(liveEventConf);
    }

    /**
     * 新增直播触发事件配置
     * 
     * @param liveEventConf 直播触发事件配置
     * @return 结果
     */
    @Override
    public int insertLiveEventConf(LiveEventConf liveEventConf)
    {
        liveEventConf.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertLiveEventConf(liveEventConf);
    }

    /**
     * 修改直播触发事件配置
     * 
     * @param liveEventConf 直播触发事件配置
     * @return 结果
     */
    @Override
    public int updateLiveEventConf(LiveEventConf liveEventConf)
    {
        return baseMapper.updateLiveEventConf(liveEventConf);
    }

    /**
     * 批量删除直播触发事件配置
     * 
     * @param eventIds 需要删除的直播触发事件配置主键
     * @return 结果
     */
    @Override
    public int deleteLiveEventConfByEventIds(Long[] eventIds)
    {
        return baseMapper.deleteLiveEventConfByEventIds(eventIds);
    }

    /**
     * 删除直播触发事件配置信息
     * 
     * @param eventId 直播触发事件配置主键
     * @return 结果
     */
    @Override
    public int deleteLiveEventConfByEventId(Long eventId)
    {
        return baseMapper.deleteLiveEventConfByEventId(eventId);
    }
}
