package com.fs.live.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.*;
import java.util.stream.Collectors;

import com.fs.common.core.domain.entity.SysUser;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.company.domain.CompanyUser;
import com.fs.his.domain.FsStoreProduct;
import com.fs.his.domain.FsStoreProduct;
import com.fs.his.mapper.FsStoreProductMapper;
import com.fs.his.domain.FsStore;
import com.fs.his.service.IFsStoreProductService;
import com.fs.his.service.IFsStoreService;
import com.fs.live.vo.LiveGoodsVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveGoodsMapper;
import com.fs.live.domain.LiveGoods;
import com.fs.live.service.ILiveGoodsService;

/**
 * 直播商品Service业务层处理
 *
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveGoodsServiceImpl extends ServiceImpl<LiveGoodsMapper, LiveGoods> implements ILiveGoodsService {

    @Autowired
    private FsStoreProductMapper fsStoreProductMapper;

    @Autowired
    private IFsStoreProductService fsStoreProductService;

    @Autowired
    private IFsStoreService fsStoreService;

    /**
     * 查询直播商品
     *
     * @param goodsId 直播商品主键
     * @return 直播商品
     */
    @Override
    public LiveGoods selectLiveGoodsByGoodsId(Long goodsId)
    {
        return baseMapper.selectLiveGoodsByGoodsId(goodsId);
    }

    /**
     * 查询直播商品列表
     *
     * @param liveGoods 直播商品
     * @return 直播商品
     */
    @Override
    public List<LiveGoods> selectLiveGoodsList(LiveGoods liveGoods)
    {
        return baseMapper.selectLiveGoodsList(liveGoods);
    }

    /**
     * 新增直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    @Override
    public int insertLiveGoods(LiveGoods liveGoods)
    {
        liveGoods.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertLiveGoods(liveGoods);
    }

    /**
     * 修改直播商品
     *
     * @param liveGoods 直播商品
     * @return 结果
     */
    @Override
    public int updateLiveGoods(LiveGoods liveGoods)
    {
        liveGoods.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateLiveGoods(liveGoods);
    }

    /**
     * 批量删除直播商品
     *
     * @param goodsIds 需要删除的直播商品主键
     * @return 结果
     */
    @Override
    public int deleteLiveGoodsByGoodsIds(Long[] goodsIds)
    {
        return baseMapper.deleteLiveGoodsByGoodsIds(goodsIds);
    }

    /**
     * 删除直播商品信息
     *
     * @param goodsId 直播商品主键
     * @return 结果
     */
    @Override
    public int deleteLiveGoodsByGoodsId(Long goodsId)
    {
        return baseMapper.deleteLiveGoodsByGoodsId(goodsId);
    }

    @Override
    public Map<String, Object> getStoreByLiveId(Long liveId) {
        Map<String, Object> map = new HashMap<>();
        //获取店铺id
        Long storeId = baseMapper.selectStoreIdByLiveId(liveId);
        if(storeId == null)
            return null;
        //获取店铺信息
        FsStore fsStore = fsStoreService.selectFsStoreByStoreId(storeId);
        //获取店铺商品信息
        FsStoreProduct fsStoreProduct = new FsStoreProduct();
        fsStoreProduct.setStoreId(fsStore.getStoreId());
        List<FsStoreProduct> fsStoreProducts = fsStoreProductService.selectFsStoreProductList(fsStoreProduct);
        map.put("store",fsStore);
        map.put("products",fsStoreProducts);
        return map;
    }



    @Override
    public List<LiveGoodsVo> selectProductListByLiveId(LiveGoods liveGoods) {
        return baseMapper.selectProductListByLiveId(liveGoods);
    }

    /**
     * 批量新增直播商品
     *
     * @param payload 包含 直播间和商品信息ids
     * @return 结果
     */
    @Override
    public int insertLiveGoods(Map<String, Object> payload, CompanyUser user) {
        Long liveId = Long.valueOf((String) payload.get("liveId"));
        String productsId = (String) payload.get("productsId");
        List<String> productIdList = new ArrayList<>(Arrays.asList(productsId.split(",")));
        if (productIdList.isEmpty()) {
            return 0;
        }
        //  查询商品信息列表（假设返回 List<StoreProduct>）
        List<FsStoreProduct> productInfoList = fsStoreProductMapper.selectFsStoreProductByProductIds(productIdList);

        //  转换为 LiveGoods 并批量插入
        List<LiveGoods> liveGoodsList = productInfoList.stream()
                .map(product -> {
                    LiveGoods liveGoods = new LiveGoods();
                    liveGoods.setLiveId(liveId);
                    liveGoods.setCompanyId(user.getCompanyId());
                    liveGoods.setCompanyUserId(user.getUserId());
                    liveGoods.setStoreId(product.getStoreId());
                    liveGoods.setProductId(product.getProductId());
                    liveGoods.setStatus(1);
                    liveGoods.setStock(Long.valueOf(product.getStock()));
                    liveGoods.setSort(product.getSort());
                    liveGoods.setCreateTime(DateUtils.getNowDate());
                    liveGoods.setCreateBy(String.valueOf(user.getUserId()));
                    return liveGoods;
                })
                .collect(Collectors.toList());
//
//        // 批量插入
        return baseMapper.insertLiveGoodsList(liveGoodsList);
    }

    @Override
    public int insertLiveGoodsAdmin(Map<String, Object> payload, SysUser user) {
        Long liveId = Long.valueOf((String) payload.get("liveId"));
        String productsId = (String) payload.get("productsId");
        List<String> productIdList = new ArrayList<>(Arrays.asList(productsId.split(",")));
        if (productIdList.isEmpty()) {
            return 0;
        }
        //  查询商品信息列表（假设返回 List<StoreProduct>）
        List<FsStoreProduct> productInfoList = fsStoreProductMapper.selectFsStoreProductByProductIds(productIdList);

        //  转换为 LiveGoods 并批量插入
        List<LiveGoods> liveGoodsList = productInfoList.stream()
                .map(product -> {
                    LiveGoods liveGoods = new LiveGoods();
                    liveGoods.setLiveId(liveId);
                    liveGoods.setStoreId(product.getStoreId());
                    liveGoods.setProductId(product.getProductId());
                    liveGoods.setStatus(1);
                    liveGoods.setStock(Long.valueOf(product.getStock()));
                    liveGoods.setSort(product.getSort());
                    liveGoods.setCreateTime(DateUtils.getNowDate());
                    liveGoods.setCreateBy(String.valueOf(user.getUserId()));
                    return liveGoods;
                })
                .collect(Collectors.toList());
//
//        // 批量插入
        return baseMapper.insertLiveGoodsList(liveGoodsList);
    }
}
