package com.fs.live.service.impl;

import java.util.Date;
import java.util.List;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.live.mapper.LiveLotteryProductConfMapper;
import com.fs.live.param.LiveLotteryProduct;
import com.fs.live.param.LiveLotteryProductSaveParam;
import com.fs.live.vo.LiveLotteryProductVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveLotteryConfMapper;
import com.fs.live.domain.LiveLotteryConf;
import com.fs.live.service.ILiveLotteryConfService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 直播抽奖配置Service业务层处理
 *
 * @author fs
 * @date 2025-07-17
 */
@Service
public class LiveLotteryConfServiceImpl extends ServiceImpl<LiveLotteryConfMapper, LiveLotteryConf> implements ILiveLotteryConfService {

    @Autowired
    private LiveLotteryConfMapper mapper;

    @Autowired
    private LiveLotteryProductConfMapper productMapper;
    /**
     * 查询直播抽奖配置
     *
     * @param lotteryId 直播抽奖配置主键
     * @return 直播抽奖配置
     */
    @Override
    public LiveLotteryConf selectLiveLotteryConfByLotteryId(Long lotteryId)
    {
        return baseMapper.selectLiveLotteryConfByLotteryId(lotteryId);
    }

    /**
     * 查询直播抽奖配置列表
     *
     * @param liveLotteryConf 直播抽奖配置
     * @return 直播抽奖配置
     */
    @Override
    public List<LiveLotteryConf> selectLiveLotteryConfList(LiveLotteryConf liveLotteryConf)
    {
        return baseMapper.selectLiveLotteryConfList(liveLotteryConf);
    }

    /**
     * 新增直播抽奖配置
     *
     * @param liveLotteryConf 直播抽奖配置
     * @return 结果
     */
    @Override
    public int insertLiveLotteryConf(LiveLotteryConf liveLotteryConf)
    {
        liveLotteryConf.setCreateTime(DateUtils.getNowDate());
        liveLotteryConf.setLotteryStatus("0");
        return baseMapper.insertLiveLotteryConf(liveLotteryConf);
    }

    /**
     * 修改直播抽奖配置
     *
     * @param liveLotteryConf 直播抽奖配置
     * @return 结果
     */
    @Override
    public String updateLiveLotteryConf(LiveLotteryConf liveLotteryConf)
    {
        if("1".equals(liveLotteryConf.getLotteryStatus())){
            List<LiveLotteryProduct> prizes = productMapper.selectLiveLotteryProductConfByLotteryId(liveLotteryConf.getLotteryId());
            if (prizes != null && !prizes.isEmpty()){
                return baseMapper.updateLiveLotteryConf(liveLotteryConf)+"";
            }else{
                return "请先添加奖品";
            }
        }
        return "1";

    }

    /**
     * 批量删除直播抽奖配置
     *
     * @param lotteryIds 需要删除的直播抽奖配置主键
     * @return 结果
     */
    @Override
    public int deleteLiveLotteryConfByLotteryIds(Long[] lotteryIds)
    {
        return baseMapper.deleteLiveLotteryConfByLotteryIds(lotteryIds);
    }

    /**
     * 删除直播抽奖配置信息
     *
     * @param lotteryId 直播抽奖配置主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteLiveLotteryConfByLotteryId(Long lotteryId)
    {
        return baseMapper.deleteLiveLotteryConfByLotteryId(lotteryId);
    }

    @Override
    @Transactional
    public LiveLotteryConf getById(Long lotteryId) {
        return mapper.selectById(lotteryId);
    }

    @Override
    @Transactional
    public List<LiveLotteryConf> getByLiveId(Long liveId) {
        return mapper.selectByLiveId(liveId);
    }

    @Override
    @Transactional
    public void create(LiveLotteryConf conf) {
        mapper.insert(conf);
    }

    @Override
    @Transactional
    public void update(LiveLotteryConf conf) {
        mapper.updateAll(conf);
    }

    @Override
    @Transactional
    public void delete(Long lotteryId) {
        mapper.deleteById(lotteryId);
    }

    @Override
    public String startLottery(Long lotteryId, Long userId) {
        LiveLotteryConf conf = mapper.selectById(lotteryId);
        if (conf == null)
            return "抽奖不存在";
        if (!"0".equals(conf.getLotteryStatus()))
            return "抽奖已开始";
        //抽奖状态
        conf.setLotteryStatus("1");
        //修改时间
        conf.setUpdateTime(new Date());
        //修改人
        conf.setUpdateBy(userId.toString());
        mapper.updateAll(conf);
        return "开始抽奖成功";
    }

    @Override
    public void saveProducts(LiveLotteryProductSaveParam liveLotteryProducts) {
        //先删除
        productMapper.deleteLiveLotteryProductConfByLotteryId(liveLotteryProducts.getLotteryId());
        liveLotteryProducts.setCreateTime(DateUtils.getNowDate());
        productMapper.saveProducts(liveLotteryProducts);
    }

    @Override
    public LiveLotteryProductVO getGoods(Long lotteryId) {
        LiveLotteryProductVO liveLotteryProductVO = new LiveLotteryProductVO();
        liveLotteryProductVO.setLotteryId(lotteryId);
        liveLotteryProductVO.setPrizes(
                productMapper.selectLiveLotteryProductConfByLotteryId(lotteryId)
        );
        return liveLotteryProductVO;
    }
}
