package com.fs.live.service.impl;

import java.util.List;
import java.util.concurrent.TimeUnit;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.common.core.domain.R;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.utils.DateUtils;
import com.fs.his.service.IFsUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveOrderMapper;
import com.fs.live.domain.LiveOrder;
import com.fs.live.service.ILiveOrderService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 订单Service业务层处理
 *
 * @author fs
 * @date 2025-07-08
 */
@Service
public class LiveOrderServiceImpl extends ServiceImpl<LiveOrderMapper, LiveOrder> implements ILiveOrderService {

    private final RedisCache redisCache;

    public LiveOrderServiceImpl(RedisCache redisCache) {
        this.redisCache = redisCache;
    }

    @Autowired
    private IFsUserService fsUserService;

    /**
     * 查询订单
     *
     * @param orderId 订单主键
     * @return 订单
     */
    @Override
    public LiveOrder selectLiveOrderByOrderId(String orderId)
    {
        return baseMapper.selectLiveOrderByOrderId(orderId);
    }

    /**
     * 查询订单列表
     *
     * @param liveOrder 订单
     * @return 订单
     */
    @Override
    public List<LiveOrder> selectLiveOrderList(LiveOrder liveOrder)
    {
        return baseMapper.selectLiveOrderList(liveOrder);
    }

    /**
     * 新增订单
     *
     * @param liveOrder 订单
     * @return 结果
     */
    @Override
    @Transactional
    public Long insertLiveOrder(LiveOrder liveOrder)
    {
        //创建时间
        liveOrder.setCreateTime(DateUtils.getNowDate());
        //订单状态 默认1
        liveOrder.setStatus(1);
        //支付状态 默认0
        liveOrder.setIsPay("0");
        //支付类型 默认1微信
        liveOrder.setPayType("1");
        baseMapper.insertLiveOrder(liveOrder);
        return liveOrder.getOrderId();
    }

    /**
     * 修改订单
     *
     * @param liveOrder 订单
     * @return 结果
     */
    @Override
    @Transactional
    public int updateLiveOrder(LiveOrder liveOrder)
    {
        liveOrder.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateLiveOrder(liveOrder);
    }

    /**
     * 批量删除订单
     *
     * @param orderIds 需要删除的订单主键
     * @return 结果
     */
    /*@Override
    public int deleteLiveOrderByOrderIds(String[] orderIds)
    {
        return baseMapper.deleteLiveOrderByOrderIds(orderIds);
    }*/

    /**
     * 删除订单信息
     *
     * @param orderId 订单主键
     * @return 结果
     */
    /*@Override
    public int deleteLiveOrderByOrderId(String orderId)
    {
        return baseMapper.deleteLiveOrderByOrderId(orderId);
    }*/

    @Override
    @Transactional
    public void handlePay(LiveOrder liveOrder) {
        //订单状态
        //插入订单详情
        //插入操作日志

    }

    @Override
    public R liveOrderUser(String liveId) {
        LiveOrder liveOrder = new LiveOrder();
        liveOrder.setLiveId(Long.parseLong(liveId));
        liveOrder.setStatus(1);
        List<LiveOrder>  list =baseMapper.selectLiveOrderList(liveOrder);
        if (list == null || list.isEmpty())
            return R.ok().put("count", 0);
        int count = list.size();
        String userName = list.get(0).getUserName();
        return R.ok().put("count",count).put("userName",userName);
    }

    /**
     * 订单操作记录
     * */
    @Transactional
    public void handleOrderStatus(LiveOrder liveOrder) {

    }
}
