package com.fs.live.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.common.utils.DateUtils;
import com.fs.live.domain.LiveVideo;
import com.fs.live.mapper.LiveVideoMapper;
import com.fs.live.service.ILiveVideoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 直播视频Service业务层处理
 *
 * @author fs
 * @date 2025-01-17
 */
@Service
public class LiveVideoServiceImpl extends ServiceImpl<LiveVideoMapper, LiveVideo> implements ILiveVideoService
{
    @Autowired
    private LiveVideoMapper liveVideoMapper;

    /**
     * 查询直播视频
     *
     * @param videoId 直播视频主键
     * @return 直播视频
     */
    @Override
    public LiveVideo selectLiveVideoByVideoId(Long videoId)
    {
        return liveVideoMapper.selectLiveVideoByVideoId(videoId);
    }

    /**
     * 查询企业直播视频
     * @param videoId       视频ID
     * @param companyId     企业ID
     * @param companyUserId 企业用户ID
     * @return LiveVideo
     */
    @Override
    public LiveVideo selectLiveVideoByVideoIdAndCompanyIdAndCompanyUserId(Long videoId, Long companyId, Long companyUserId)
    {
        return liveVideoMapper.selectLiveVideoByVideoIdAndCompanyIdAndCompanyUserId(videoId, companyId, companyUserId);
    }

    /**
     * 查询直播视频列表
     *
     * @param liveVideo 直播视频
     * @return 直播视频
     */
    @Override
    public List<LiveVideo> selectLiveVideoList(LiveVideo liveVideo)
    {
        return liveVideoMapper.selectLiveVideoList(liveVideo);
    }

    /**
     * 新增直播视频
     *
     * @param liveVideo 直播视频
     * @return 结果
     */
    @Override
    public int insertLiveVideo(LiveVideo liveVideo)
    {
        liveVideo.setCreateTime(DateUtils.getNowDate());
        return liveVideoMapper.insertLiveVideo(liveVideo);
    }

    /**
     * 修改直播视频
     *
     * @param liveVideo 直播视频
     * @return 结果
     */
    @Override
    public int updateLiveVideo(LiveVideo liveVideo)
    {
        liveVideo.setUpdateTime(DateUtils.getNowDate());
        return liveVideoMapper.updateLiveVideo(liveVideo);
    }

    /**
     * 批量删除直播视频
     *
     * @param videoIds 需要删除的直播视频主键
     * @return 结果
     */
    @Override
    public int deleteLiveVideoByVideoIds(Long[] videoIds)
    {
        return liveVideoMapper.deleteLiveVideoByVideoIds(videoIds);
    }

    /**
     * 删除直播视频信息
     *
     * @param videoId 直播视频主键
     * @return 结果
     */
    @Override
    public int deleteLiveVideoByVideoId(Long videoId)
    {
        return liveVideoMapper.deleteLiveVideoByVideoId(videoId);
    }

    @Override
    public List<LiveVideo> listByLiveId(Long liveId, Integer type) {
        return list(new QueryWrapper<LiveVideo>().eq("live_id", liveId).eq("video_type", type));
    }

    /**
     * 根据直播ID查询视频
     * @param liveId 直播ID
     * @return liveVideo
     */
    @Override
    public LiveVideo selectLiveVideoByLiveId(Long liveId) {
        Wrapper<LiveVideo> wrapper = new LambdaQueryWrapper<LiveVideo>().eq(LiveVideo::getLiveId, liveId).last("limit 1");
        return baseMapper.selectOne(wrapper);
    }

}
