package com.fs.qw.service;

import com.fs.common.core.domain.R;
import com.fs.qw.domain.QwTagGroup;
import com.fs.qw.vo.QwTagGroupAddParam;
import com.fs.qw.vo.QwTagGroupListVO;
import com.fs.qw.vo.QwTagGroupVO;

import java.util.List;

/**
 * 企微客户标签组Service接口
 *
 * @author fs
 * @date 2024-06-20
 */
public interface IQwTagGroupService
{
    /**
     * 查询企微客户标签组
     *
     * @param id 企微客户标签组主键
     * @return 企微客户标签组
     */
    public QwTagGroup selectQwTagGroupById(Long id);

    /**
     * 查询企微客户标签组列表
     *
     * @param qwTagGroup 企微客户标签组
     * @return 企微客户标签组集合
     */
    public List<QwTagGroup> selectQwTagGroupList(QwTagGroup qwTagGroup);

    /**
     * 新增企微客户标签组
     *
     * @param qwTagGroup 企微客户标签组
     * @return 结果
     */
    public int insertQwTagGroup(QwTagGroup qwTagGroup);

    /**
     * 修改企微客户标签组
     *
     * @param qwTagGroup 企微客户标签组
     * @return 结果
     */
    public int updateQwTagGroup(QwTagGroup qwTagGroup);

    /**
     * 批量删除企微客户标签组
     *
     * @param ids 需要删除的企微客户标签组主键集合
     * @return 结果
     */
    public R deleteQwTagGroupByIds(Long[] ids);

    /**
     * 删除企微客户标签组信息
     *
     * @param id 企微客户标签组主键
     * @return 结果
     */
    public int deleteQwTagGroupById(Long id);

    R syncQwTagGroup(String corpId);

    List<QwTagGroupListVO> selectQwTagGroupListVO(QwTagGroup qwTagGroup);

    List<QwTagGroupListVO> selectQwGroupTagList(QwTagGroup qwTagGroup);

    QwTagGroupVO selectQwTagGroupByIdVO(Long id);

    int insertQwTagGroupParam(QwTagGroupAddParam qwTagGroup);

    int updateQwTagGroupParam(QwTagGroupAddParam qwTagGroup);

    void addTagByTagId(String tagType, String tagId, String corpId);

    void shuffleTagByTagId(String id, String corpId);

    void deleteTagByTagId(String tagType, String id, String corpId);

    void updateTagByTagId(String tagType, String id, String corpId);

    void addQwTagByAi(String trimTag, Long extId);

    void delQwTagByAi(String trimTag, Long extId);
}
